@@ -5,12 +5,13 @@ import (
 	"testing"
 	"time"
 
+	"github.com/stretchr/testify/require"
+
 	"github.com/influxdata/telegraf/metric"
 	"github.com/influxdata/telegraf/testutil"
-	"github.com/stretchr/testify/assert"
 )
 
-var m1, _ = metric.New("m1",
+var m1 = metric.New("m1",
 	map[string]string{"foo": "bar"},
 	map[string]interface{}{
 		"a": int64(1),
@@ -21,7 +22,7 @@ var m1, _ = metric.New("m1",
 	},
 	time.Date(2000, 1, 1, 0, 0, 0, 0, time.UTC),
 )
-var m2, _ = metric.New("m1",
+var m2 = metric.New("m1",
 	map[string]string{"foo": "bar"},
 	map[string]interface{}{
 		"a":        int64(1),
@@ -184,7 +185,6 @@ func TestBasicStatsDifferentPeriods(t *testing.T) {
 
 // Test only aggregating count
 func TestBasicStatsWithOnlyCount(t *testing.T) {
-
 	aggregator := NewBasicStats()
 	aggregator.Stats = []string{"count"}
 	aggregator.Log = testutil.Logger{}
@@ -213,7 +213,6 @@ func TestBasicStatsWithOnlyCount(t *testing.T) {
 
 // Test only aggregating minimum
 func TestBasicStatsWithOnlyMin(t *testing.T) {
-
 	aggregator := NewBasicStats()
 	aggregator.Stats = []string{"min"}
 	aggregator.Log = testutil.Logger{}
@@ -242,7 +241,6 @@ func TestBasicStatsWithOnlyMin(t *testing.T) {
 
 // Test only aggregating maximum
 func TestBasicStatsWithOnlyMax(t *testing.T) {
-
 	aggregator := NewBasicStats()
 	aggregator.Stats = []string{"max"}
 	aggregator.Log = testutil.Logger{}
@@ -271,7 +269,6 @@ func TestBasicStatsWithOnlyMax(t *testing.T) {
 
 // Test only aggregating mean
 func TestBasicStatsWithOnlyMean(t *testing.T) {
-
 	aggregator := NewBasicStats()
 	aggregator.Stats = []string{"mean"}
 	aggregator.Log = testutil.Logger{}
@@ -300,7 +297,6 @@ func TestBasicStatsWithOnlyMean(t *testing.T) {
 
 // Test only aggregating sum
 func TestBasicStatsWithOnlySum(t *testing.T) {
-
 	aggregator := NewBasicStats()
 	aggregator.Stats = []string{"sum"}
 	aggregator.Log = testutil.Logger{}
@@ -331,29 +327,28 @@ func TestBasicStatsWithOnlySum(t *testing.T) {
 // implementations of sum were calculated from mean and count, which
 // e.g. summed "1, 1, 5, 1" as "7.999999..." instead of 8.
 func TestBasicStatsWithOnlySumFloatingPointErrata(t *testing.T) {
-
-	var sum1, _ = metric.New("m1",
+	var sum1 = metric.New("m1",
 		map[string]string{},
 		map[string]interface{}{
 			"a": int64(1),
 		},
 		time.Now(),
 	)
-	var sum2, _ = metric.New("m1",
+	var sum2 = metric.New("m1",
 		map[string]string{},
 		map[string]interface{}{
 			"a": int64(1),
 		},
 		time.Now(),
 	)
-	var sum3, _ = metric.New("m1",
+	var sum3 = metric.New("m1",
 		map[string]string{},
 		map[string]interface{}{
 			"a": int64(5),
 		},
 		time.Now(),
 	)
-	var sum4, _ = metric.New("m1",
+	var sum4 = metric.New("m1",
 		map[string]string{},
 		map[string]interface{}{
 			"a": int64(1),
@@ -383,7 +378,6 @@ func TestBasicStatsWithOnlySumFloatingPointErrata(t *testing.T) {
 
 // Test only aggregating variance
 func TestBasicStatsWithOnlyVariance(t *testing.T) {
-
 	aggregator := NewBasicStats()
 	aggregator.Stats = []string{"s2"}
 	aggregator.Log = testutil.Logger{}
@@ -410,7 +404,6 @@ func TestBasicStatsWithOnlyVariance(t *testing.T) {
 
 // Test only aggregating standard deviation
 func TestBasicStatsWithOnlyStandardDeviation(t *testing.T) {
-
 	aggregator := NewBasicStats()
 	aggregator.Stats = []string{"stdev"}
 	aggregator.Log = testutil.Logger{}
@@ -437,7 +430,6 @@ func TestBasicStatsWithOnlyStandardDeviation(t *testing.T) {
 
 // Test only aggregating minimum and maximum
 func TestBasicStatsWithMinAndMax(t *testing.T) {
-
 	aggregator := NewBasicStats()
 	aggregator.Stats = []string{"min", "max"}
 	aggregator.Log = testutil.Logger{}
@@ -473,7 +465,6 @@ func TestBasicStatsWithMinAndMax(t *testing.T) {
 
 // Test only aggregating diff
 func TestBasicStatsWithDiff(t *testing.T) {
-
 	aggregator := NewBasicStats()
 	aggregator.Stats = []string{"diff"}
 	aggregator.Log = testutil.Logger{}
@@ -499,7 +490,6 @@ func TestBasicStatsWithDiff(t *testing.T) {
 }
 
 func TestBasicStatsWithRate(t *testing.T) {
-
 	aggregator := NewBasicStats()
 	aggregator.Stats = []string{"rate"}
 	aggregator.Log = testutil.Logger{}
@@ -524,7 +514,6 @@ func TestBasicStatsWithRate(t *testing.T) {
 }
 
 func TestBasicStatsWithNonNegativeRate(t *testing.T) {
-
 	aggregator := NewBasicStats()
 	aggregator.Stats = []string{"non_negative_rate"}
 	aggregator.Log = testutil.Logger{}
@@ -547,8 +536,32 @@ func TestBasicStatsWithNonNegativeRate(t *testing.T) {
 	}
 	acc.AssertContainsTaggedFields(t, "m1", expectedFields, expectedTags)
 }
-func TestBasicStatsWithInterval(t *testing.T) {
 
+func TestBasicStatsWithPctChange(t *testing.T) {
+	aggregator := NewBasicStats()
+	aggregator.Stats = []string{"percent_change"}
+	aggregator.Log = testutil.Logger{}
+	aggregator.getConfiguredStats()
+
+	aggregator.Add(m1)
+	aggregator.Add(m2)
+
+	acc := testutil.Accumulator{}
+	aggregator.Push(&acc)
+	expectedFields := map[string]interface{}{
+		"a_percent_change": float64(0),
+		"b_percent_change": float64(200),
+		"c_percent_change": float64(100),
+		"d_percent_change": float64(200),
+		"g_percent_change": float64(-66.66666666666666),
+	}
+	expectedTags := map[string]string{
+		"foo": "bar",
+	}
+	acc.AssertContainsTaggedFields(t, "m1", expectedFields, expectedTags)
+}
+
+func TestBasicStatsWithInterval(t *testing.T) {
 	aggregator := NewBasicStats()
 	aggregator.Stats = []string{"interval"}
 	aggregator.Log = testutil.Logger{}
@@ -575,7 +588,6 @@ func TestBasicStatsWithInterval(t *testing.T) {
 
 // Test only aggregating non_negative_diff
 func TestBasicStatsWithNonNegativeDiff(t *testing.T) {
-
 	aggregator := NewBasicStats()
 	aggregator.Stats = []string{"non_negative_diff"}
 	aggregator.Log = testutil.Logger{}
@@ -666,7 +678,6 @@ func TestBasicStatsWithAllStats(t *testing.T) {
 
 // Test that if an empty array is passed, no points are pushed
 func TestBasicStatsWithNoStats(t *testing.T) {
-
 	aggregator := NewBasicStats()
 	aggregator.Stats = []string{}
 	aggregator.Log = testutil.Logger{}
@@ -683,7 +694,6 @@ func TestBasicStatsWithNoStats(t *testing.T) {
 
 // Test that if an unknown stat is configured, it doesn't explode
 func TestBasicStatsWithUnknownStat(t *testing.T) {
-
 	aggregator := NewBasicStats()
 	aggregator.Stats = []string{"crazy"}
 	aggregator.Log = testutil.Logger{}
@@ -703,7 +713,6 @@ func TestBasicStatsWithUnknownStat(t *testing.T) {
 // otherwise user's working systems will suddenly (and surprisingly) start
 // capturing sum without their input.
 func TestBasicStatsWithDefaultStats(t *testing.T) {
-
 	aggregator := NewBasicStats()
 	aggregator.Log = testutil.Logger{}
 	aggregator.getConfiguredStats()
@@ -714,11 +723,11 @@ func TestBasicStatsWithDefaultStats(t *testing.T) {
 	acc := testutil.Accumulator{}
 	aggregator.Push(&acc)
 
-	assert.True(t, acc.HasField("m1", "a_count"))
-	assert.True(t, acc.HasField("m1", "a_min"))
-	assert.True(t, acc.HasField("m1", "a_max"))
-	assert.True(t, acc.HasField("m1", "a_mean"))
-	assert.True(t, acc.HasField("m1", "a_stdev"))
-	assert.True(t, acc.HasField("m1", "a_s2"))
-	assert.False(t, acc.HasField("m1", "a_sum"))
+	require.True(t, acc.HasField("m1", "a_count"))
+	require.True(t, acc.HasField("m1", "a_min"))
+	require.True(t, acc.HasField("m1", "a_max"))
+	require.True(t, acc.HasField("m1", "a_mean"))
+	require.True(t, acc.HasField("m1", "a_stdev"))
+	require.True(t, acc.HasField("m1", "a_s2"))
+	require.False(t, acc.HasField("m1", "a_sum"))
 }
