@@ -7,6 +7,7 @@ import (
 	"time"
 
 	"github.com/benbjohnson/clock"
+	"github.com/peterbourgon/unixtransport"
 
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/config"
@@ -50,6 +51,9 @@ func (h *HTTPClientConfig) CreateClient(ctx context.Context, log telegraf.Logger
 		ResponseHeaderTimeout: time.Duration(h.ResponseHeaderTimeout),
 	}
 
+	// Register "http+unix" and "https+unix" protocol handler.
+	unixtransport.Register(transport)
+
 	timeout := h.Timeout
 	if timeout == 0 {
 		timeout = config.Duration(time.Second * 5)
