@@ -1,12 +1,13 @@
 package kafka
 
 import (
-	"fmt"
+	"errors"
 	"math"
 	"strings"
 	"time"
 
-	"github.com/Shopify/sarama"
+	"github.com/IBM/sarama"
+
 	"github.com/influxdata/telegraf"
 	tgConf "github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/plugins/common/tls"
@@ -54,10 +55,11 @@ type Config struct {
 	SASLAuth
 	tls.ClientConfig
 
-	Version          string `toml:"version"`
-	ClientID         string `toml:"client_id"`
-	CompressionCodec int    `toml:"compression_codec"`
-	EnableTLS        *bool  `toml:"enable_tls"`
+	Version          string           `toml:"version"`
+	ClientID         string           `toml:"client_id"`
+	CompressionCodec int              `toml:"compression_codec"`
+	EnableTLS        *bool            `toml:"enable_tls"`
+	KeepAlivePeriod  *tgConf.Duration `toml:"keep_alive_period"`
 
 	MetadataRetryMax         int             `toml:"metadata_retry_max"`
 	MetadataRetryType        string          `toml:"metadata_retry_type"`
@@ -71,7 +73,7 @@ type Config struct {
 type BackoffFunc func(retries, maxRetries int) time.Duration
 
 func makeBackoffFunc(backoff, maxDuration time.Duration) BackoffFunc {
-	return func(retries, maxRetries int) time.Duration {
+	return func(retries, _ int) time.Duration {
 		d := time.Duration(math.Pow(2, float64(retries))) * backoff
 		if maxDuration != 0 && d > maxDuration {
 			return maxDuration
@@ -118,6 +120,11 @@ func (k *Config) SetConfig(config *sarama.Config, log telegraf.Logger) error {
 		}
 	}
 
+	if k.KeepAlivePeriod != nil {
+		// Defaults to OS setting (15s currently)
+		config.Net.KeepAlive = time.Duration(*k.KeepAlivePeriod)
+	}
+
 	if k.MetadataFull != nil {
 		// Defaults to true in Sarama
 		config.Metadata.Full = *k.MetadataFull
@@ -135,7 +142,7 @@ func (k *Config) SetConfig(config *sarama.Config, log telegraf.Logger) error {
 
 	switch strings.ToLower(k.MetadataRetryType) {
 	default:
-		return fmt.Errorf("invalid metadata retry type")
+		return errors.New("invalid metadata retry type")
 	case "exponential":
 		if k.MetadataRetryBackoff == 0 {
 			k.MetadataRetryBackoff = tgConf.Duration(250 * time.Millisecond)
