@@ -25,7 +25,7 @@ type expectedResult struct {
 
 func TestParseSockId(t *testing.T) {
 	s := parseSockID(sockFile(osdPrefix, 1), osdPrefix, sockSuffix)
-	require.Equal(t, s, "1")
+	require.Equal(t, "1", s)
 }
 
 func TestParseMonDump(t *testing.T) {
@@ -69,6 +69,15 @@ func TestDecodeStatus(t *testing.T) {
 		acc.AssertContainsTaggedFields(t, r.metric, r.fields, r.tags)
 	}
 }
+func TestDecodeStatusNestedOSD(t *testing.T) {
+	acc := &testutil.Accumulator{}
+	err := decodeStatus(acc, clusterStatusDumpNestedOSD)
+	require.NoError(t, err)
+
+	for _, r := range cephStatusResultsNestedOSD {
+		acc.AssertContainsTaggedFields(t, r.metric, r.fields, r.tags)
+	}
+}
 
 func TestDecodeDf(t *testing.T) {
 	acc := &testutil.Accumulator{}
@@ -98,11 +107,11 @@ func TestGather(t *testing.T) {
 		perfDump = saveDump
 	}()
 
-	findSockets = func(c *Ceph) ([]*socket, error) {
+	findSockets = func(*Ceph) ([]*socket, error) {
 		return []*socket{{"osd.1", typeOsd, ""}}, nil
 	}
 
-	perfDump = func(binary string, s *socket) (string, error) {
+	perfDump = func(string, *socket) (string, error) {
 		return osdPerfDump, nil
 	}
 
@@ -164,11 +173,10 @@ func assertFoundSocket(t *testing.T, dir, sockType string, i int, sockets []*soc
 	expected := filepath.Join(dir, sockFile(prefix, i))
 	found := false
 	for _, s := range sockets {
-		_, err := fmt.Printf("Checking %s\n", s.socket)
-		require.NoError(t, err)
+		fmt.Printf("Checking %s\n", s.socket)
 		if s.socket == expected {
 			found = true
-			require.Equal(t, s.sockType, sockType, "Unexpected socket type for '%s'", s)
+			require.Equal(t, s.sockType, sockType, "Unexpected socket type for %q", s)
 			require.Equal(t, s.sockID, strconv.Itoa(i))
 		}
 	}
@@ -183,7 +191,7 @@ func createTestFiles(dir string, st *SockTest) error {
 	writeFile := func(prefix string, i int) error {
 		f := sockFile(prefix, i)
 		fpath := filepath.Join(dir, f)
-		return os.WriteFile(fpath, []byte(""), 0644)
+		return os.WriteFile(fpath, []byte(""), 0640)
 	}
 	return tstFileApply(st, writeFile)
 }
@@ -769,6 +777,7 @@ var osdPerfDump = `
       "wait": { "avgcount": 0,
           "sum": 0.000000000}}}
 `
+
 var mdsPerfDump = `
 {
     "AsyncMessenger::Worker-0": {
@@ -1761,159 +1770,185 @@ var rgwPerfDump = `
 
 var clusterStatusDump = `
 {
-  "health": {
     "health": {
-      "health_services": [
-        {
-          "mons": [
-            {
-              "name": "a",
-              "kb_total": 114289256,
-              "kb_used": 26995516,
-              "kb_avail": 81465132,
-              "avail_percent": 71,
-              "last_updated": "2017-01-03 17:20:57.595004",
-              "store_stats": {
-                "bytes_total": 942117141,
-                "bytes_sst": 0,
-                "bytes_log": 4345406,
-                "bytes_misc": 937771735,
-                "last_updated": "0.000000"
-              },
-              "health": "HEALTH_OK"
-            },
-            {
-              "name": "b",
-              "kb_total": 114289256,
-              "kb_used": 27871624,
-              "kb_avail": 80589024,
-              "avail_percent": 70,
-              "last_updated": "2017-01-03 17:20:47.784331",
-              "store_stats": {
-                "bytes_total": 454853104,
-                "bytes_sst": 0,
-                "bytes_log": 5788320,
-                "bytes_misc": 449064784,
-                "last_updated": "0.000000"
-              },
-              "health": "HEALTH_OK"
-            },
-            {
-              "name": "c",
-              "kb_total": 130258508,
-              "kb_used": 38076996,
-              "kb_avail": 85541692,
-              "avail_percent": 65,
-              "last_updated": "2017-01-03 17:21:03.311123",
-              "store_stats": {
-                "bytes_total": 455555199,
-                "bytes_sst": 0,
-                "bytes_log": 6950876,
-                "bytes_misc": 448604323,
-                "last_updated": "0.000000"
-              },
-              "health": "HEALTH_OK"
-            }
-          ]
-        }
-      ]
+        "status": "HEALTH_OK",
+        "checks": {},
+        "mutes": []
     },
-    "timechecks": {
-      "epoch": 504,
-      "round": 34642,
-      "round_status": "finished",
-      "mons": [
-        { "name": "a", "skew": 0, "latency": 0, "health": "HEALTH_OK" },
-        { "name": "b", "skew": -0, "latency": 0.000951, "health": "HEALTH_OK" },
-        { "name": "c", "skew": -0, "latency": 0.000946, "health": "HEALTH_OK" }
-      ]
-    },
-    "summary": [],
-    "overall_status": "HEALTH_OK",
-    "detail": []
-  },
-  "fsid": "01234567-abcd-9876-0123-ffeeddccbbaa",
-  "election_epoch": 504,
-  "quorum": [ 0, 1, 2 ],
-  "quorum_names": [ "a", "b", "c" ],
-  "monmap": {
-    "epoch": 17,
     "fsid": "01234567-abcd-9876-0123-ffeeddccbbaa",
-    "modified": "2016-04-11 14:01:52.600198",
-    "created": "0.000000",
-    "mons": [
-      { "rank": 0, "name": "a", "addr": "192.168.0.1:6789/0" },
-      { "rank": 1, "name": "b", "addr": "192.168.0.2:6789/0" },
-      { "rank": 2, "name": "c", "addr": "192.168.0.3:6789/0" }
-    ]
-  },
-  "osdmap": {
-    "osdmap": {
-      "epoch": 21734,
-      "num_osds": 24,
-      "num_up_osds": 24,
-      "num_in_osds": 24,
-      "full": false,
-      "nearfull": false,
-      "num_remapped_pgs": 0
-    }
-  },
-  "pgmap": {
-    "pgs_by_state": [
-      { "state_name": "active+clean", "count": 2560 },
-      { "state_name": "active+scrubbing", "count": 10 },
-      { "state_name": "active+backfilling", "count": 5 }
+    "election_epoch": 504,
+    "quorum": [
+        0,
+        1,
+        2
     ],
-    "version": 52314277,
-    "num_pgs": 2560,
-    "data_bytes": 2700031960713,
-    "bytes_used": 7478347665408,
-    "bytes_avail": 9857462382592,
-    "bytes_total": 17335810048000,
-    "read_bytes_sec": 0,
-    "write_bytes_sec": 367217,
-    "op_per_sec": 98,
-    "read_op_per_sec": 322,
-    "write_op_per_sec": 1022
-  },
-  "mdsmap": {
-    "epoch": 1,
-    "up": 0,
-    "in": 0,
-    "max": 0,
-    "by_rank": []
-  }
+    "quorum_names": [
+        "a",
+        "b",
+        "c"
+    ],
+    "monmap": {
+        "epoch": 27,
+        "min_mon_release_name": "pacific",
+        "num_mons": 3
+    },
+    "osdmap": {
+        "epoch": 21734,
+        "num_osds": 24,
+        "num_up_osds": 24,
+        "osd_up_since": 1646008974,
+        "num_in_osds": 24,
+        "osd_in_since": 1637261831,
+        "num_remapped_pgs": 0
+    },
+    "pgmap": {
+        "pgs_by_state": [
+            {
+                "state_name": "active+clean",
+                "count": 2560
+            },
+            {
+                "state_name": "active+scrubbing",
+                "count": 10
+            },
+            {
+                "state_name": "active+backfilling",
+                "count": 5
+            }
+        ],
+        "version": 52314277,
+        "num_pgs": 2560,
+        "num_pools": 4,
+        "num_objects": 974827,
+        "data_bytes": 2700031960713,
+        "bytes_used": 7478347665408,
+        "bytes_avail": 9857462382592,
+        "bytes_total": 17335810048000,
+        "inactive_pgs_ratio": 0.19742488861083984,
+        "degraded_objects": 25919,
+        "degraded_total": 2920050,
+        "degraded_ratio": 0.008876217872981627,
+        "recovering_objects_per_sec": 6,
+        "recovering_bytes_per_sec": 223303,
+        "recovering_keys_per_sec": 10,
+        "num_objects_recovered": 40,
+        "num_bytes_recovered": 1335808,
+        "num_keys_recovered": 64,
+        "read_bytes_sec": 0,
+        "write_bytes_sec": 367217,
+        "read_op_per_sec": 322,
+        "write_op_per_sec": 1022
+    },
+    "mdsmap": {
+        "epoch": 1,
+        "up": 0,
+        "in": 0,
+        "max": 0,
+        "by_rank": []
+    },
+    "fsmap": {
+        "epoch": 24756,
+        "id": 4,
+        "up": 1,
+        "in": 1,
+        "max": 1,
+        "by_rank": [
+            {
+                "filesystem_id": 4,
+                "rank": 0,
+                "name": "a",
+                "status": "up:active",
+                "gid": 83585495
+            }
+        ],
+        "up:standby": 2
+    },
+    "mgrmap": {
+        "available": true,
+        "num_standbys": 2,
+        "modules": [
+            "dashboard",
+            "iostat",
+            "restful",
+            "stats"
+        ],
+        "services": {
+            "dashboard": "https://192.168.0.1:8443/"
+        }
+    },
+    "servicemap": {
+        "epoch": 219919,
+        "modified": "2022-03-07T13:52:42.430153-0500",
+        "services": {}
+    },
+    "progress_events": {}
 }
 `
 
 var cephStatusResults = []expectedResult{
+	{
+		metric: "ceph_fsmap",
+		fields: map[string]interface{}{
+			"in":         float64(1),
+			"max":        float64(1),
+			"up_standby": float64(2),
+			"up":         float64(1),
+		},
+		tags: map[string]string{},
+	},
+	{
+		metric: "ceph_health",
+		fields: map[string]interface{}{
+			"overall_status": "",
+			"status_code":    float64(2),
+			"status":         "HEALTH_OK",
+		},
+		tags: map[string]string{},
+	},
+	{
+		metric: "ceph_monmap",
+		fields: map[string]interface{}{
+			"num_mons": float64(3),
+		},
+		tags: map[string]string{},
+	},
 	{
 		metric: "ceph_osdmap",
 		fields: map[string]interface{}{
 			"epoch":            float64(21734),
-			"num_osds":         float64(24),
-			"num_up_osds":      float64(24),
 			"num_in_osds":      float64(24),
-			"full":             false,
-			"nearfull":         false,
+			"num_osds":         float64(24),
 			"num_remapped_pgs": float64(0),
+			"num_up_osds":      float64(24),
 		},
 		tags: map[string]string{},
 	},
 	{
 		metric: "ceph_pgmap",
 		fields: map[string]interface{}{
-			"version":          float64(52314277),
-			"num_pgs":          float64(2560),
-			"data_bytes":       float64(2700031960713),
-			"bytes_used":       float64(7478347665408),
-			"bytes_avail":      float64(9857462382592),
-			"bytes_total":      float64(17335810048000),
-			"read_bytes_sec":   float64(0),
-			"write_bytes_sec":  float64(367217),
-			"op_per_sec":       pf(98),
-			"read_op_per_sec":  float64(322),
-			"write_op_per_sec": float64(1022),
+			"bytes_avail":                float64(9857462382592),
+			"bytes_total":                float64(17335810048000),
+			"bytes_used":                 float64(7478347665408),
+			"data_bytes":                 float64(2700031960713),
+			"degraded_objects":           float64(25919),
+			"degraded_ratio":             float64(0.0088762178729816267),
+			"degraded_total":             float64(2920050),
+			"inactive_pgs_ratio":         float64(0.19742488861083984),
+			"num_bytes_recovered":        float64(1335808),
+			"num_keys_recovered":         float64(64),
+			"num_objects_recovered":      float64(40),
+			"num_objects":                float64(974827),
+			"num_pgs":                    float64(2560),
+			"num_pools":                  float64(4),
+			"op_per_sec":                 float64(0), // exists only in ceph <10
+			"read_bytes_sec":             float64(0),
+			"read_op_per_sec":            float64(322),
+			"recovering_bytes_per_sec":   float64(223303),
+			"recovering_keys_per_sec":    float64(10),
+			"recovering_objects_per_sec": float64(6),
+			"version":                    float64(52314277),
+			"write_bytes_sec":            float64(367217),
+			"write_op_per_sec":           float64(1022),
 		},
 		tags: map[string]string{},
 	},
@@ -1946,145 +1981,391 @@ var cephStatusResults = []expectedResult{
 	},
 }
 
+var clusterStatusDumpNestedOSD = `
+{
+    "health": {
+        "status": "HEALTH_OK",
+        "checks": {},
+        "mutes": []
+    },
+    "fsid": "01234567-abcd-9876-0123-ffeeddccbbaa",
+    "election_epoch": 504,
+    "quorum": [
+        0,
+        1,
+        2
+    ],
+    "quorum_names": [
+        "a",
+        "b",
+        "c"
+    ],
+    "monmap": {
+        "epoch": 27,
+        "min_mon_release_name": "pacific",
+        "num_mons": 3
+    },
+    "osdmap": {
+        "osdmap": {
+            "epoch": 21734,
+            "num_osds": 24,
+            "num_up_osds": 24,
+            "osd_up_since": 1646008974,
+            "num_in_osds": 24,
+            "osd_in_since": 1637261831,
+            "num_remapped_pgs": 0
+        }
+    },
+    "pgmap": {
+        "pgs_by_state": [
+            {
+                "state_name": "active+clean",
+                "count": 2560
+            },
+            {
+                "state_name": "active+scrubbing",
+                "count": 10
+            },
+            {
+                "state_name": "active+backfilling",
+                "count": 5
+            }
+        ],
+        "version": 52314277,
+        "num_pgs": 2560,
+        "num_pools": 4,
+        "num_objects": 974827,
+        "data_bytes": 2700031960713,
+        "bytes_used": 7478347665408,
+        "bytes_avail": 9857462382592,
+        "bytes_total": 17335810048000,
+        "inactive_pgs_ratio": 0.19742488861083984,
+        "degraded_objects": 25919,
+        "degraded_total": 2920050,
+        "degraded_ratio": 0.008876217872981627,
+        "recovering_objects_per_sec": 6,
+        "recovering_bytes_per_sec": 223303,
+        "recovering_keys_per_sec": 10,
+        "num_objects_recovered": 40,
+        "num_bytes_recovered": 1335808,
+        "num_keys_recovered": 64,
+        "read_bytes_sec": 0,
+        "write_bytes_sec": 367217,
+        "read_op_per_sec": 322,
+        "write_op_per_sec": 1022
+    },
+    "mdsmap": {
+        "epoch": 1,
+        "up": 0,
+        "in": 0,
+        "max": 0,
+        "by_rank": []
+    },
+    "fsmap": {
+        "epoch": 24756,
+        "id": 4,
+        "up": 1,
+        "in": 1,
+        "max": 1,
+        "by_rank": [
+            {
+                "filesystem_id": 4,
+                "rank": 0,
+                "name": "a",
+                "status": "up:active",
+                "gid": 83585495
+            }
+        ],
+        "up:standby": 2
+    },
+    "mgrmap": {
+        "available": true,
+        "num_standbys": 2,
+        "modules": [
+            "dashboard",
+            "iostat",
+            "restful",
+            "stats"
+        ],
+        "services": {
+            "dashboard": "https://192.168.0.1:8443/"
+        }
+    },
+    "servicemap": {
+        "epoch": 219919,
+        "modified": "2022-03-07T13:52:42.430153-0500",
+        "services": {}
+    },
+    "progress_events": {}
+}
+`
+
+var cephStatusResultsNestedOSD = []expectedResult{
+	{
+		metric: "ceph_osdmap",
+		fields: map[string]interface{}{
+			"epoch":            float64(21734),
+			"full":             false,
+			"nearfull":         false,
+			"num_in_osds":      float64(24),
+			"num_osds":         float64(24),
+			"num_remapped_pgs": float64(0),
+			"num_up_osds":      float64(24),
+		},
+		tags: map[string]string{},
+	},
+}
+
 var cephDFDump = `
-{ "stats": { "total_space": 472345880,
-      "total_used": 71058504,
-      "total_avail": 377286864,
-      "total_bytes": 472345880,
-      "total_used_bytes": 71058504,
-      "total_avail_bytes": 377286864},
-  "pools": [
-        { "name": "data",
-          "id": 0,
-          "stats": { "kb_used": 0,
-              "bytes_used": 0,
-              "objects": 0}},
-        { "name": "metadata",
-          "id": 1,
-          "stats": { "kb_used": 25,
-              "bytes_used": 25052,
-              "objects": 53}},
-        { "name": "rbd",
-          "id": 2,
-          "stats": { "kb_used": 0,
-              "bytes_used": 0,
-              "objects": 0}},
-        { "name": "test",
-          "id": 3,
-          "stats": { "kb_used": 55476,
-              "bytes_used": 56806602,
-              "objects": 1}}]}`
+{
+    "stats": {
+        "total_bytes": 14882929901568,
+        "total_avail_bytes": 7866135064576,
+        "total_used_bytes": 7016794836992,
+        "total_used_raw_bytes": 7016794836992,
+        "total_used_raw_ratio": 0.47146594524383545,
+        "num_osds": 6,
+        "num_per_pool_osds": 6,
+        "num_per_pool_omap_osds": 6
+    },
+    "stats_by_class": {
+        "hdd": {
+            "total_bytes": 12002349023232,
+            "total_avail_bytes": 6080040206336,
+            "total_used_bytes": 5922308816896,
+            "total_used_raw_bytes": 5922308816896,
+            "total_used_raw_ratio": 0.49342915415763855
+        },
+        "ssd": {
+            "total_bytes": 2880580878336,
+            "total_avail_bytes": 1786094858240,
+            "total_used_bytes": 1094486020096,
+            "total_used_raw_bytes": 1094486020096,
+            "total_used_raw_ratio": 0.3799532353878021
+        }
+    },
+    "pools": [
+        {
+            "name": "foo",
+            "id": 4,
+            "stats": {
+                "stored": 672914410122,
+                "objects": 161029,
+                "kb_used": 1972149256,
+                "bytes_used": 2019480838046,
+                "percent_used": 0.2692900002002716,
+                "max_avail": 1826599337984
+            }
+        },
+        {
+            "name": "bar_metadata",
+            "id": 12,
+            "stats": {
+                "stored": 1486436928,
+                "objects": 88452,
+                "kb_used": 4354883,
+                "bytes_used": 4459399953,
+                "percent_used": 0.0027088995557278395,
+                "max_avail": 547248046080
+            }
+        },
+        {
+            "name": "bar_data",
+            "id": 13,
+            "stats": {
+                "stored": 1291824398336,
+                "objects": 522694,
+                "kb_used": 3800912960,
+                "bytes_used": 3892134871040,
+                "percent_used": 0.41529691219329834,
+                "max_avail": 1826599337984
+            }
+        },
+        {
+            "name": "device_health_metrics",
+            "id": 17,
+            "stats": {
+                "stored": 42634584,
+                "objects": 9,
+                "kb_used": 83271,
+                "bytes_used": 85269164,
+                "percent_used": 0.000012548729500849731,
+                "max_avail": 3397479301120
+            }
+        }
+    ]
+}
+`
 
 var cephDfResults = []expectedResult{
 	{
 		metric: "ceph_usage",
 		fields: map[string]interface{}{
-			"total_space":       pf(472345880),
-			"total_used":        pf(71058504),
-			"total_avail":       pf(377286864),
-			"total_bytes":       pf(472345880),
-			"total_used_bytes":  pf(71058504),
-			"total_avail_bytes": pf(377286864),
+			"num_osds":               float64(6),
+			"num_per_pool_omap_osds": float64(6),
+			"num_per_pool_osds":      float64(6),
+			"total_avail_bytes":      float64(7866135064576),
+			"total_avail":            float64(0), // pre ceph 0.84
+			"total_bytes":            float64(14882929901568),
+			"total_space":            float64(0), // pre ceph 0.84
+			"total_used_bytes":       float64(7016794836992),
+			"total_used_raw_bytes":   float64(7016794836992),
+			"total_used_raw_ratio":   float64(0.47146594524383545),
+			"total_used":             float64(0), // pre ceph 0.84
 		},
 		tags: map[string]string{},
 	},
 	{
 		metric: "ceph_pool_usage",
 		fields: map[string]interface{}{
-			"kb_used":      float64(0),
-			"bytes_used":   float64(0),
-			"objects":      float64(0),
-			"percent_used": (*float64)(nil),
-			"max_avail":    (*float64)(nil),
+			"bytes_used":   float64(2019480838046),
+			"kb_used":      float64(1972149256),
+			"max_avail":    float64(1826599337984),
+			"objects":      float64(161029),
+			"percent_used": float64(0.26929000020027161),
+			"stored":       float64(672914410122),
 		},
 		tags: map[string]string{
-			"name": "data",
+			"name": "foo",
 		},
 	},
 	{
 		metric: "ceph_pool_usage",
 		fields: map[string]interface{}{
-			"kb_used":      float64(25),
-			"bytes_used":   float64(25052),
-			"objects":      float64(53),
-			"percent_used": (*float64)(nil),
-			"max_avail":    (*float64)(nil),
+			"bytes_used":   float64(4459399953),
+			"kb_used":      float64(4354883),
+			"max_avail":    float64(547248046080),
+			"objects":      float64(88452),
+			"percent_used": float64(0.0027088995557278395),
+			"stored":       float64(1486436928),
 		},
 		tags: map[string]string{
-			"name": "metadata",
+			"name": "bar_metadata",
 		},
 	},
 	{
 		metric: "ceph_pool_usage",
 		fields: map[string]interface{}{
-			"kb_used":      float64(0),
-			"bytes_used":   float64(0),
-			"objects":      float64(0),
-			"percent_used": (*float64)(nil),
-			"max_avail":    (*float64)(nil),
+			"bytes_used":   float64(3892134871040),
+			"kb_used":      float64(3800912960),
+			"max_avail":    float64(1826599337984),
+			"objects":      float64(522694),
+			"percent_used": float64(0.41529691219329834),
+			"stored":       float64(1291824398336),
 		},
 		tags: map[string]string{
-			"name": "rbd",
+			"name": "bar_data",
 		},
 	},
 	{
 		metric: "ceph_pool_usage",
 		fields: map[string]interface{}{
-			"kb_used":      float64(55476),
-			"bytes_used":   float64(56806602),
-			"objects":      float64(1),
-			"percent_used": (*float64)(nil),
-			"max_avail":    (*float64)(nil),
+			"bytes_used":   float64(85269164),
+			"kb_used":      float64(83271),
+			"max_avail":    float64(3397479301120),
+			"objects":      float64(9),
+			"percent_used": float64(0.000012548729500849731),
+			"stored":       float64(42634584),
 		},
 		tags: map[string]string{
-			"name": "test",
+			"name": "device_health_metrics",
+		},
+	},
+	{
+		metric: "ceph_deviceclass_usage",
+		fields: map[string]interface{}{
+			"total_avail_bytes":    float64(6080040206336),
+			"total_bytes":          float64(12002349023232),
+			"total_used_bytes":     float64(5922308816896),
+			"total_used_raw_bytes": float64(5922308816896),
+			"total_used_raw_ratio": float64(0.49342915415763855),
+		},
+		tags: map[string]string{
+			"class": "hdd",
+		},
+	},
+	{
+		metric: "ceph_deviceclass_usage",
+		fields: map[string]interface{}{
+			"total_avail_bytes":    float64(1786094858240),
+			"total_bytes":          float64(2880580878336),
+			"total_used_bytes":     float64(1094486020096),
+			"total_used_raw_bytes": float64(1094486020096),
+			"total_used_raw_ratio": float64(0.3799532353878021),
+		},
+		tags: map[string]string{
+			"class": "ssd",
 		},
 	},
 }
 
 var cephODSPoolStatsDump = `
 [
-    { "pool_name": "data",
-      "pool_id": 0,
-      "recovery": {},
-      "recovery_rate": {},
-      "client_io_rate": {}},
-    { "pool_name": "metadata",
-      "pool_id": 1,
-      "recovery": {},
-      "recovery_rate": {},
-      "client_io_rate": {}},
-    { "pool_name": "rbd",
-      "pool_id": 2,
-      "recovery": {},
-      "recovery_rate": {},
-      "client_io_rate": {}},
-    { "pool_name": "pbench",
-      "pool_id": 3,
-      "recovery": { "degraded_objects": 18446744073709551562,
-          "degraded_total": 412,
-          "degrated_ratio": "-13.107"},
-      "recovery_rate": { "recovering_objects_per_sec": 279,
-          "recovering_bytes_per_sec": 176401059,
-          "recovering_keys_per_sec": 0},
-      "client_io_rate": { "read_bytes_sec": 10566067,
-          "write_bytes_sec": 15165220376,
-          "op_per_sec": 9828,
-          "read_op_per_sec": 182,
-          "write_op_per_sec": 473}}]`
+    {
+        "pool_name": "data",
+        "pool_id": 0,
+        "recovery": {
+            "degraded_objects": 12,
+            "degraded_total": 483087,
+            "degraded_ratio": 0.000024840246166839513
+        },
+        "recovery_rate": {},
+        "client_io_rate": {}
+    },
+    {
+        "pool_name": "metadata",
+        "pool_id": 1,
+        "recovery": {},
+        "recovery_rate": {},
+        "client_io_rate": {}
+    },
+    {
+        "pool_name": "rbd",
+        "pool_id": 2,
+        "recovery": {},
+        "recovery_rate": {},
+        "client_io_rate": {}
+    },
+    {
+        "pool_name": "pbench",
+        "pool_id": 3,
+        "recovery": {},
+        "recovery_rate": {
+            "recovering_objects_per_sec": 16,
+            "recovering_bytes_per_sec": 0,
+            "recovering_keys_per_sec": 0,
+            "num_objects_recovered": 200,
+            "num_bytes_recovered": 0,
+            "num_keys_recovered": 0
+        },
+        "client_io_rate": {
+            "read_bytes_sec": 10566067,
+            "write_bytes_sec": 15165220376,
+            "read_op_per_sec": 182,
+            "write_op_per_sec": 473
+        }
+    }
+]
+`
 
 var cephOSDPoolStatsResults = []expectedResult{
 	{
 		metric: "ceph_pool_stats",
 		fields: map[string]interface{}{
+			"degraded_objects":           float64(12),
+			"degraded_ratio":             float64(0.000024840246166839513),
+			"degraded_total":             float64(483087),
+			"num_bytes_recovered":        float64(0),
+			"num_keys_recovered":         float64(0),
+			"num_objects_recovered":      float64(0),
+			"op_per_sec":                 float64(0), // This field is no longer reported in ceph 10 and later
 			"read_bytes_sec":             float64(0),
-			"write_bytes_sec":            float64(0),
-			"op_per_sec":                 (*float64)(nil),
 			"read_op_per_sec":            float64(0),
-			"write_op_per_sec":           float64(0),
-			"recovering_objects_per_sec": float64(0),
 			"recovering_bytes_per_sec":   float64(0),
 			"recovering_keys_per_sec":    float64(0),
+			"recovering_objects_per_sec": float64(0),
+			"write_bytes_sec":            float64(0),
+			"write_op_per_sec":           float64(0),
 		},
 		tags: map[string]string{
 			"name": "data",
@@ -2093,21 +2374,45 @@ var cephOSDPoolStatsResults = []expectedResult{
 	{
 		metric: "ceph_pool_stats",
 		fields: map[string]interface{}{
-			"read_bytes_sec":             float64(10566067),
-			"write_bytes_sec":            float64(15165220376),
-			"op_per_sec":                 pf(9828),
-			"read_op_per_sec":            float64(182),
-			"write_op_per_sec":           float64(473),
-			"recovering_objects_per_sec": float64(279),
-			"recovering_bytes_per_sec":   float64(176401059),
+			"degraded_objects":           float64(0),
+			"degraded_ratio":             float64(0),
+			"degraded_total":             float64(0),
+			"num_bytes_recovered":        float64(0),
+			"num_keys_recovered":         float64(0),
+			"num_objects_recovered":      float64(0),
+			"op_per_sec":                 float64(0), // This field is no longer reported in ceph 10 and later
+			"read_bytes_sec":             float64(0),
+			"read_op_per_sec":            float64(0),
+			"recovering_bytes_per_sec":   float64(0),
 			"recovering_keys_per_sec":    float64(0),
+			"recovering_objects_per_sec": float64(0),
+			"write_bytes_sec":            float64(0),
+			"write_op_per_sec":           float64(0),
+		},
+		tags: map[string]string{
+			"name": "metadata",
+		},
+	},
+	{
+		metric: "ceph_pool_stats",
+		fields: map[string]interface{}{
+			"degraded_objects":           float64(0),
+			"degraded_ratio":             float64(0),
+			"degraded_total":             float64(0),
+			"num_bytes_recovered":        float64(0),
+			"num_keys_recovered":         float64(0),
+			"num_objects_recovered":      float64(200),
+			"op_per_sec":                 float64(0), // This field is no longer reported in ceph 10 and later
+			"read_bytes_sec":             float64(10566067),
+			"read_op_per_sec":            float64(182),
+			"recovering_bytes_per_sec":   float64(0),
+			"recovering_keys_per_sec":    float64(0),
+			"recovering_objects_per_sec": float64(16),
+			"write_bytes_sec":            float64(15165220376),
+			"write_op_per_sec":           float64(473),
 		},
 		tags: map[string]string{
 			"name": "pbench",
 		},
 	},
 }
-
-func pf(i float64) *float64 {
-	return &i
-}
