@@ -10,8 +10,8 @@ import (
 
 	"github.com/stretchr/testify/require"
 
+	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/plugins/inputs"
-	"github.com/influxdata/telegraf/plugins/parsers"
 	"github.com/influxdata/telegraf/plugins/parsers/csv"
 	"github.com/influxdata/telegraf/plugins/parsers/json"
 	"github.com/influxdata/telegraf/testutil"
@@ -53,7 +53,7 @@ func TestCSVGZImport(t *testing.T) {
 	err := r.Init()
 	require.NoError(t, err)
 
-	r.SetParserFunc(func() (parsers.Parser, error) {
+	r.SetParserFunc(func() (telegraf.Parser, error) {
 		parser := csv.Parser{
 			HeaderRowCount: 1,
 		}
@@ -89,7 +89,7 @@ func TestCSVGZImport(t *testing.T) {
 	r.Stop()
 
 	// Verify that we read both files once.
-	require.Equal(t, len(acc.Metrics), 6)
+	require.Len(t, acc.Metrics, 6)
 
 	// File should have gone back to the test directory, as we configured.
 	_, err = os.Stat(filepath.Join(finishedDirectory, testCsvFile))
@@ -119,7 +119,7 @@ func TestCSVGZImportWithHeader(t *testing.T) {
 	err := r.Init()
 	require.NoError(t, err)
 
-	r.SetParserFunc(func() (parsers.Parser, error) {
+	r.SetParserFunc(func() (telegraf.Parser, error) {
 		parser := csv.Parser{
 			HeaderRowCount: 1,
 			SkipRows:       1,
@@ -160,7 +160,7 @@ func TestCSVGZImportWithHeader(t *testing.T) {
 	r.Stop()
 
 	// Verify that we read both files once.
-	require.Equal(t, len(acc.Metrics), 6)
+	require.Len(t, acc.Metrics, 6)
 
 	// File should have gone back to the test directory, as we configured.
 	_, err = os.Stat(filepath.Join(finishedDirectory, testCsvFile))
@@ -189,7 +189,7 @@ func TestMultipleJSONFileImports(t *testing.T) {
 	err := r.Init()
 	require.NoError(t, err)
 
-	r.SetParserFunc(func() (parsers.Parser, error) {
+	r.SetParserFunc(func() (telegraf.Parser, error) {
 		p := &json.Parser{NameKey: "Name"}
 		err := p.Init()
 		return p, err
@@ -217,7 +217,7 @@ func TestMultipleJSONFileImports(t *testing.T) {
 	r.Stop()
 
 	// Verify that we read each JSON line once to a single metric.
-	require.Equal(t, len(acc.Metrics), 5)
+	require.Len(t, acc.Metrics, 5)
 }
 
 func TestFileTag(t *testing.T) {
@@ -240,7 +240,7 @@ func TestFileTag(t *testing.T) {
 	err := r.Init()
 	require.NoError(t, err)
 
-	r.SetParserFunc(func() (parsers.Parser, error) {
+	r.SetParserFunc(func() (telegraf.Parser, error) {
 		p := &json.Parser{NameKey: "Name"}
 		err := p.Init()
 		return p, err
@@ -264,7 +264,7 @@ func TestFileTag(t *testing.T) {
 	r.Stop()
 
 	// Verify that we read each JSON line once to a single metric.
-	require.Equal(t, len(acc.Metrics), 1)
+	require.Len(t, acc.Metrics, 1)
 	for _, m := range acc.Metrics {
 		for key, value := range m.Tags {
 			require.Equal(t, r.FileTag, key)
@@ -292,7 +292,7 @@ func TestCSVNoSkipRows(t *testing.T) {
 	err := r.Init()
 	require.NoError(t, err)
 
-	r.SetParserFunc(func() (parsers.Parser, error) {
+	r.SetParserFunc(func() (telegraf.Parser, error) {
 		parser := csv.Parser{
 			HeaderRowCount: 1,
 			SkipRows:       0,
@@ -328,7 +328,7 @@ hello,80,test_name2`
 	r.Stop()
 
 	// Verify that we read both files once.
-	require.Equal(t, len(acc.Metrics), 1)
+	require.Len(t, acc.Metrics, 1)
 
 	// File should have gone back to the test directory, as we configured.
 	_, err = os.Stat(filepath.Join(finishedDirectory, testCsvFile))
@@ -361,7 +361,7 @@ func TestCSVSkipRows(t *testing.T) {
 	err := r.Init()
 	require.NoError(t, err)
 
-	r.SetParserFunc(func() (parsers.Parser, error) {
+	r.SetParserFunc(func() (telegraf.Parser, error) {
 		parser := csv.Parser{
 			HeaderRowCount: 1,
 			SkipRows:       2,
@@ -399,7 +399,7 @@ hello,80,test_name2`
 	r.Stop()
 
 	// Verify that we read both files once.
-	require.Equal(t, len(acc.Metrics), 1)
+	require.Len(t, acc.Metrics, 1)
 
 	// File should have gone back to the test directory, as we configured.
 	_, err = os.Stat(filepath.Join(finishedDirectory, testCsvFile))
@@ -432,7 +432,7 @@ func TestCSVMultiHeader(t *testing.T) {
 	err := r.Init()
 	require.NoError(t, err)
 
-	r.SetParserFunc(func() (parsers.Parser, error) {
+	r.SetParserFunc(func() (telegraf.Parser, error) {
 		parser := csv.Parser{
 			HeaderRowCount: 2,
 			TagColumns:     []string{"line1"},
@@ -468,7 +468,7 @@ hello,80,test_name2`
 	r.Stop()
 
 	// Verify that we read both files once.
-	require.Equal(t, len(acc.Metrics), 1)
+	require.Len(t, acc.Metrics, 1)
 
 	// File should have gone back to the test directory, as we configured.
 	_, err = os.Stat(filepath.Join(finishedDirectory, testCsvFile))
@@ -501,7 +501,7 @@ func TestParseCompleteFile(t *testing.T) {
 	require.NoError(t, err)
 	r.Log = testutil.Logger{}
 
-	r.SetParserFunc(func() (parsers.Parser, error) {
+	r.SetParserFunc(func() (telegraf.Parser, error) {
 		parser := &json.Parser{
 			NameKey: "name",
 			TagKeys: []string{"tag1"},
@@ -553,7 +553,7 @@ func TestParseSubdirectories(t *testing.T) {
 	require.NoError(t, err)
 	r.Log = testutil.Logger{}
 
-	r.SetParserFunc(func() (parsers.Parser, error) {
+	r.SetParserFunc(func() (telegraf.Parser, error) {
 		parser := &json.Parser{
 			NameKey: "name",
 			TagKeys: []string{"tag1"},
@@ -631,7 +631,7 @@ func TestParseSubdirectoriesFilesIgnore(t *testing.T) {
 	require.NoError(t, err)
 	r.Log = testutil.Logger{}
 
-	r.SetParserFunc(func() (parsers.Parser, error) {
+	r.SetParserFunc(func() (telegraf.Parser, error) {
 		parser := &json.Parser{
 			NameKey: "name",
 			TagKeys: []string{"tag1"},
