@@ -4,26 +4,28 @@ package dpdk
 
 import (
 	"encoding/json"
-	"fmt"
+	"errors"
 	"testing"
 
 	"github.com/stretchr/testify/mock"
 	"github.com/stretchr/testify/require"
 
 	"github.com/influxdata/telegraf/plugins/inputs/dpdk/mocks"
+	"github.com/influxdata/telegraf/testutil"
 )
 
 func Test_readMaxOutputLen(t *testing.T) {
 	t.Run("should return error if timeout occurred", func(t *testing.T) {
 		conn := &mocks.Conn{}
-		conn.On("Read", mock.Anything).Return(0, fmt.Errorf("timeout"))
+		conn.On("Read", mock.Anything).Return(0, errors.New("timeout"))
 		conn.On("SetDeadline", mock.Anything).Return(nil)
 		connector := dpdkConnector{connection: conn}
 
-		_, err := connector.readMaxOutputLen()
+		initMessage, err := connector.readInitMessage()
 
 		require.Error(t, err)
 		require.Contains(t, err.Error(), "timeout")
+		require.Empty(t, initMessage)
 	})
 
 	t.Run("should pass and set maxOutputLen if provided with valid InitMessage", func(t *testing.T) {
@@ -43,10 +45,10 @@ func Test_readMaxOutputLen(t *testing.T) {
 		conn.On("SetDeadline", mock.Anything).Return(nil)
 		connector := dpdkConnector{connection: conn}
 
-		_, err = connector.readMaxOutputLen()
+		initMsg, err := connector.readInitMessage()
 
 		require.NoError(t, err)
-		require.Equal(t, maxOutputLen, connector.maxOutputLen)
+		require.Equal(t, maxOutputLen, initMsg.MaxOutputLen)
 	})
 
 	t.Run("should fail if received invalid json", func(t *testing.T) {
@@ -59,7 +61,7 @@ func Test_readMaxOutputLen(t *testing.T) {
 		conn.On("SetDeadline", mock.Anything).Return(nil)
 		connector := dpdkConnector{connection: conn}
 
-		_, err := connector.readMaxOutputLen()
+		_, err := connector.readInitMessage()
 
 		require.Error(t, err)
 		require.Contains(t, err.Error(), "looking for beginning of object key string")
@@ -80,7 +82,7 @@ func Test_readMaxOutputLen(t *testing.T) {
 		conn.On("SetDeadline", mock.Anything).Return(nil)
 		connector := dpdkConnector{connection: conn}
 
-		_, err = connector.readMaxOutputLen()
+		_, err = connector.readInitMessage()
 
 		require.Error(t, err)
 		require.Contains(t, err.Error(), "failed to read maxOutputLen information")
@@ -89,15 +91,14 @@ func Test_readMaxOutputLen(t *testing.T) {
 
 func Test_connect(t *testing.T) {
 	t.Run("should pass if PathToSocket points to socket", func(t *testing.T) {
-		pathToSocket, socket := createSocketForTest(t)
-		defer socket.Close()
+		pathToSocket, socket := createSocketForTest(t, "")
 		dpdk := dpdk{
 			SocketPath: pathToSocket,
-			connector:  newDpdkConnector(pathToSocket, 0),
+			connectors: []*dpdkConnector{newDpdkConnector(pathToSocket, 0)},
 		}
 		go simulateSocketResponse(socket, t)
 
-		_, err := dpdk.connector.connect()
+		_, err := dpdk.connectors[0].connect()
 
 		require.NoError(t, err)
 	})
@@ -112,60 +113,62 @@ func Test_getCommandResponse(t *testing.T) {
 		defer mockConn.AssertExpectations(t)
 		simulateResponse(mockConn, response, nil)
 
-		buf, err := dpdk.connector.getCommandResponse(command)
+		for _, connector := range dpdk.connectors {
+			buf, err := connector.getCommandResponse(command)
 
-		require.NoError(t, err)
-		require.Equal(t, len(response), len(buf))
-		require.Equal(t, response, string(buf))
+			require.NoError(t, err)
+			require.Equal(t, len(response), len(buf))
+			require.Equal(t, response, string(buf))
+		}
 	})
 
 	t.Run("should return error if failed to get connection handler", func(t *testing.T) {
 		_, dpdk, _ := prepareEnvironment()
-		dpdk.connector.connection = nil
+		dpdk.connectors[0].connection = nil
 
-		buf, err := dpdk.connector.getCommandResponse(command)
+		buf, err := dpdk.connectors[0].getCommandResponse(command)
 
 		require.Error(t, err)
 		require.Contains(t, err.Error(), "failed to get connection to execute \"/\" command")
-		require.Equal(t, 0, len(buf))
+		require.Empty(t, buf)
 	})
 
 	t.Run("should return error if failed to set timeout duration", func(t *testing.T) {
 		mockConn, dpdk, _ := prepareEnvironment()
 		defer mockConn.AssertExpectations(t)
-		mockConn.On("SetDeadline", mock.Anything).Return(fmt.Errorf("deadline error"))
+		mockConn.On("SetDeadline", mock.Anything).Return(errors.New("deadline error"))
 
-		buf, err := dpdk.connector.getCommandResponse(command)
+		buf, err := dpdk.connectors[0].getCommandResponse(command)
 
 		require.Error(t, err)
 		require.Contains(t, err.Error(), "deadline error")
-		require.Equal(t, 0, len(buf))
+		require.Empty(t, buf)
 	})
 
 	t.Run("should return error if timeout occurred during Write operation", func(t *testing.T) {
 		mockConn, dpdk, _ := prepareEnvironment()
 		defer mockConn.AssertExpectations(t)
-		mockConn.On("Write", mock.Anything).Return(0, fmt.Errorf("write timeout"))
+		mockConn.On("Write", mock.Anything).Return(0, errors.New("write timeout"))
 		mockConn.On("SetDeadline", mock.Anything).Return(nil)
 		mockConn.On("Close").Return(nil)
 
-		buf, err := dpdk.connector.getCommandResponse(command)
+		buf, err := dpdk.connectors[0].getCommandResponse(command)
 
 		require.Error(t, err)
 		require.Contains(t, err.Error(), "write timeout")
-		require.Equal(t, 0, len(buf))
+		require.Empty(t, buf)
 	})
 
 	t.Run("should return error if timeout occurred during Read operation", func(t *testing.T) {
 		mockConn, dpdk, _ := prepareEnvironment()
 		defer mockConn.AssertExpectations(t)
-		simulateResponse(mockConn, "", fmt.Errorf("read timeout"))
+		simulateResponse(mockConn, "", errors.New("read timeout"))
 
-		buf, err := dpdk.connector.getCommandResponse(command)
+		buf, err := dpdk.connectors[0].getCommandResponse(command)
 
 		require.Error(t, err)
 		require.Contains(t, err.Error(), "read timeout")
-		require.Equal(t, 0, len(buf))
+		require.Empty(t, buf)
 	})
 
 	t.Run("should return error if got empty response", func(t *testing.T) {
@@ -173,10 +176,65 @@ func Test_getCommandResponse(t *testing.T) {
 		defer mockConn.AssertExpectations(t)
 		simulateResponse(mockConn, "", nil)
 
-		buf, err := dpdk.connector.getCommandResponse(command)
+		buf, err := dpdk.connectors[0].getCommandResponse(command)
 
 		require.Error(t, err)
-		require.Equal(t, 0, len(buf))
+		require.Empty(t, buf)
 		require.Contains(t, err.Error(), "got empty response during execution of")
 	})
 }
+
+func Test_processCommand(t *testing.T) {
+	t.Run("should pass if received valid response", func(t *testing.T) {
+		mockConn, dpdk, mockAcc := prepareEnvironment()
+		defer mockConn.AssertExpectations(t)
+		response := `{"/": ["/", "/eal/app_params", "/eal/params", "/ethdev/link_status, /ethdev/info"]}`
+		simulateResponse(mockConn, response, nil)
+
+		for _, dpdkConn := range dpdk.connectors {
+			dpdkConn.processCommand(mockAcc, testutil.Logger{}, "/", nil)
+		}
+
+		require.Empty(t, mockAcc.Errors)
+	})
+
+	t.Run("if received a non-JSON object then should return error", func(t *testing.T) {
+		mockConn, dpdk, mockAcc := prepareEnvironment()
+		defer mockConn.AssertExpectations(t)
+		response := `notAJson`
+		simulateResponse(mockConn, response, nil)
+
+		for _, dpdkConn := range dpdk.connectors {
+			dpdkConn.processCommand(mockAcc, testutil.Logger{}, "/", nil)
+		}
+
+		require.Len(t, mockAcc.Errors, 1)
+		require.Contains(t, mockAcc.Errors[0].Error(), "invalid character")
+	})
+
+	t.Run("if failed to get command response then accumulator should contain error", func(t *testing.T) {
+		mockConn, dpdk, mockAcc := prepareEnvironment()
+		defer mockConn.AssertExpectations(t)
+		mockConn.On("Write", mock.Anything).Return(0, errors.New("deadline exceeded"))
+		mockConn.On("SetDeadline", mock.Anything).Return(nil)
+		mockConn.On("Close").Return(nil)
+		for _, dpdkConn := range dpdk.connectors {
+			dpdkConn.processCommand(mockAcc, testutil.Logger{}, "/", nil)
+		}
+
+		require.Len(t, mockAcc.Errors, 1)
+		require.Contains(t, mockAcc.Errors[0].Error(), "deadline exceeded")
+	})
+
+	t.Run("if response contains nil or empty value then error shouldn't be returned in accumulator", func(t *testing.T) {
+		mockConn, dpdk, mockAcc := prepareEnvironment()
+		defer mockConn.AssertExpectations(t)
+		response := `{"/test": null}`
+		simulateResponse(mockConn, response, nil)
+		for _, dpdkConn := range dpdk.connectors {
+			dpdkConn.processCommand(mockAcc, testutil.Logger{}, "/test,param", nil)
+		}
+
+		require.Empty(t, mockAcc.Errors)
+	})
+}
