@@ -4,6 +4,7 @@ package elasticsearch_query
 import (
 	"context"
 	_ "embed"
+	"errors"
 	"fmt"
 	"net/http"
 	"strconv"
@@ -15,7 +16,7 @@ import (
 
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/config"
-	"github.com/influxdata/telegraf/plugins/common/tls"
+	httpconfig "github.com/influxdata/telegraf/plugins/common/http"
 	"github.com/influxdata/telegraf/plugins/inputs"
 )
 
@@ -28,15 +29,15 @@ type ElasticsearchQuery struct {
 	Username            string          `toml:"username"`
 	Password            string          `toml:"password"`
 	EnableSniffer       bool            `toml:"enable_sniffer"`
-	Timeout             config.Duration `toml:"timeout"`
 	HealthCheckInterval config.Duration `toml:"health_check_interval"`
 	Aggregations        []esAggregation `toml:"aggregation"`
 
 	Log telegraf.Logger `toml:"-"`
 
-	tls.ClientConfig
 	httpclient *http.Client
-	esClient   *elastic5.Client
+	httpconfig.HTTPClientConfig
+
+	esClient *elastic5.Client
 }
 
 // esAggregation struct
@@ -63,7 +64,7 @@ func (*ElasticsearchQuery) SampleConfig() string {
 // Init the plugin.
 func (e *ElasticsearchQuery) Init() error {
 	if e.URLs == nil {
-		return fmt.Errorf("elasticsearch urls is not defined")
+		return errors.New("elasticsearch urls is not defined")
 	}
 
 	err := e.connectToES()
@@ -77,10 +78,10 @@ func (e *ElasticsearchQuery) Init() error {
 
 	for i, agg := range e.Aggregations {
 		if agg.MeasurementName == "" {
-			return fmt.Errorf("field 'measurement_name' is not set")
+			return errors.New("field 'measurement_name' is not set")
 		}
 		if agg.DateField == "" {
-			return fmt.Errorf("field 'date_field' is not set")
+			return errors.New("field 'date_field' is not set")
 		}
 		err = e.initAggregation(ctx, agg, i)
 		if err != nil {
@@ -160,7 +161,7 @@ func (e *ElasticsearchQuery) connectToES() error {
 
 	// quit if ES version is not supported
 	if len(esVersionSplit) == 0 {
-		return fmt.Errorf("elasticsearch version check failed")
+		return errors.New("elasticsearch version check failed")
 	}
 
 	i, err := strconv.Atoi(esVersionSplit[0])
@@ -197,20 +198,8 @@ func (e *ElasticsearchQuery) Gather(acc telegraf.Accumulator) error {
 }
 
 func (e *ElasticsearchQuery) createHTTPClient() (*http.Client, error) {
-	tlsCfg, err := e.ClientConfig.TLSConfig()
-	if err != nil {
-		return nil, err
-	}
-	tr := &http.Transport{
-		ResponseHeaderTimeout: time.Duration(e.Timeout),
-		TLSClientConfig:       tlsCfg,
-	}
-	httpclient := &http.Client{
-		Transport: tr,
-		Timeout:   time.Duration(e.Timeout),
-	}
-
-	return httpclient, nil
+	ctx := context.Background()
+	return e.HTTPClientConfig.CreateClient(ctx, e.Log)
 }
 
 func (e *ElasticsearchQuery) esAggregationQuery(acc telegraf.Accumulator, aggregation esAggregation, i int) error {
@@ -242,8 +231,11 @@ func (e *ElasticsearchQuery) esAggregationQuery(acc telegraf.Accumulator, aggreg
 func init() {
 	inputs.Add("elasticsearch_query", func() telegraf.Input {
 		return &ElasticsearchQuery{
-			Timeout:             config.Duration(time.Second * 5),
 			HealthCheckInterval: config.Duration(time.Second * 10),
+			HTTPClientConfig: httpconfig.HTTPClientConfig{
+				ResponseHeaderTimeout: config.Duration(5 * time.Second),
+				Timeout:               config.Duration(5 * time.Second),
+			},
 		}
 	})
 }
