@@ -5,6 +5,7 @@ import (
 	"context"
 	_ "embed"
 	"fmt"
+	"strconv"
 	"sync"
 	"time"
 
@@ -14,7 +15,6 @@ import (
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/internal"
 	"github.com/influxdata/telegraf/plugins/inputs"
-	"github.com/influxdata/telegraf/plugins/parsers"
 )
 
 //go:embed sample.conf
@@ -64,7 +64,7 @@ type EventHub struct {
 	cancel context.CancelFunc
 	wg     sync.WaitGroup
 
-	parser parsers.Parser
+	parser telegraf.Parser
 	in     chan []telegraf.Metric
 }
 
@@ -73,7 +73,7 @@ func (*EventHub) SampleConfig() string {
 }
 
 // SetParser sets the parser
-func (e *EventHub) SetParser(parser parsers.Parser) {
+func (e *EventHub) SetParser(parser telegraf.Parser) {
 	e.parser = parser
 }
 
@@ -296,7 +296,7 @@ func (e *EventHub) createMetrics(event *eventhubClient.Event) ([]telegraf.Metric
 		}
 
 		if event.SystemProperties.PartitionID != nil && e.PartitionIDTag != "" {
-			metrics[i].AddTag(e.PartitionIDTag, fmt.Sprintf("%d", *event.SystemProperties.PartitionID))
+			metrics[i].AddTag(e.PartitionIDTag, strconv.Itoa(int(*event.SystemProperties.PartitionID)))
 		}
 		if event.SystemProperties.PartitionKey != nil && e.PartitionKeyTag != "" {
 			metrics[i].AddTag(e.PartitionKeyTag, *event.SystemProperties.PartitionKey)
