@@ -4,6 +4,7 @@ package github
 import (
 	"context"
 	_ "embed"
+	"errors"
 	"fmt"
 	"net/http"
 	"strings"
@@ -148,10 +149,11 @@ func (g *GitHub) Gather(acc telegraf.Accumulator) error {
 }
 
 func (g *GitHub) handleRateLimit(response *githubLib.Response, err error) {
+	var rlErr *githubLib.RateLimitError
 	if err == nil {
 		g.RateLimit.Set(int64(response.Rate.Limit))
 		g.RateRemaining.Set(int64(response.Rate.Remaining))
-	} else if _, ok := err.(*githubLib.RateLimitError); ok {
+	} else if errors.As(err, &rlErr) {
 		g.RateLimitErrors.Incr(1)
 	}
 }
@@ -214,7 +216,7 @@ func (g *GitHub) getPullRequestFields(ctx context.Context, owner, repo string) (
 			return fields, err
 		}
 
-		f := fmt.Sprintf("%s_pull_requests", class)
+		f := class + "_pull_requests"
 		fields[f] = searchResult.GetTotal()
 	}
 
