@@ -4,9 +4,8 @@ package gnmi
 import (
 	"context"
 	_ "embed"
+	"errors"
 	"fmt"
-	"path"
-	"regexp"
 	"strings"
 	"sync"
 	"time"
@@ -25,9 +24,6 @@ import (
 //go:embed sample.conf
 var sampleConfig string
 
-// Regular expression to see if a path element contains an origin
-var originPattern = regexp.MustCompile(`^([\w-_]+):`)
-
 // Define the warning to show if we cannot get a metric name.
 const emptyNameWarning = `Got empty metric-name for response, usually indicating
 configuration issues as the response cannot be related to any subscription.
@@ -58,41 +54,37 @@ type GNMI struct {
 	Trace               bool              `toml:"dump_responses"`
 	CanonicalFieldNames bool              `toml:"canonical_field_names"`
 	TrimFieldNames      bool              `toml:"trim_field_names"`
+	GuessPathTag        bool              `toml:"guess_path_tag" deprecated:"1.30.0;use 'path_guessing_strategy' instead"`
+	GuessPathStrategy   string            `toml:"path_guessing_strategy"`
 	EnableTLS           bool              `toml:"enable_tls" deprecated:"1.27.0;use 'tls_enable' instead"`
 	Log                 telegraf.Logger   `toml:"-"`
 	internaltls.ClientConfig
 
 	// Internal state
-	internalAliases map[string]string
+	internalAliases map[*pathInfo]string
 	cancel          context.CancelFunc
 	wg              sync.WaitGroup
 }
 
 // Subscription for a gNMI client
 type Subscription struct {
-	Name   string
-	Origin string
-	Path   string
-
-	fullPath *gnmiLib.Path
-
-	// Subscription mode and interval
-	SubscriptionMode string          `toml:"subscription_mode"`
-	SampleInterval   config.Duration `toml:"sample_interval"`
-
-	// Duplicate suppression
+	Name              string          `toml:"name"`
+	Origin            string          `toml:"origin"`
+	Path              string          `toml:"path"`
+	SubscriptionMode  string          `toml:"subscription_mode"`
+	SampleInterval    config.Duration `toml:"sample_interval"`
 	SuppressRedundant bool            `toml:"suppress_redundant"`
 	HeartbeatInterval config.Duration `toml:"heartbeat_interval"`
+	TagOnly           bool            `toml:"tag_only" deprecated:"1.25.0;2.0.0;please use 'tag_subscription's instead"`
 
-	// Mark this subscription as a tag-only lookup source, not emitting any metric
-	TagOnly bool `toml:"tag_only" deprecated:"1.25.0;2.0.0;please use 'tag_subscription's instead"`
+	fullPath *gnmiLib.Path
 }
 
 // Tag Subscription for a gNMI client
 type TagSubscription struct {
 	Subscription
-	Match    string `toml:"match"`
-	Elements []string
+	Match    string   `toml:"match"`
+	Elements []string `toml:"elements"`
 }
 
 func (*GNMI) SampleConfig() string {
@@ -102,7 +94,7 @@ func (*GNMI) SampleConfig() string {
 func (c *GNMI) Init() error {
 	// Check options
 	if time.Duration(c.Redial) <= 0 {
-		return fmt.Errorf("redial duration must be positive")
+		return errors.New("redial duration must be positive")
 	}
 
 	// Check vendor_specific options configured by user
@@ -110,6 +102,21 @@ func (c *GNMI) Init() error {
 		return fmt.Errorf("unsupported vendor_specific option: %w", err)
 	}
 
+	// Check path guessing and handle deprecated option
+	if c.GuessPathTag {
+		if c.GuessPathStrategy == "" {
+			c.GuessPathStrategy = "common path"
+		}
+		if c.GuessPathStrategy != "common path" {
+			return errors.New("conflicting settings between 'guess_path_tag' and 'path_guessing_strategy'")
+		}
+	}
+	switch c.GuessPathStrategy {
+	case "", "none", "common path", "subscription":
+	default:
+		return fmt.Errorf("invalid 'path_guessing_strategy' %q", c.GuessPathStrategy)
+	}
+
 	// Use the new TLS option for enabling
 	// Honor deprecated option
 	enable := (c.ClientConfig.Enable != nil && *c.ClientConfig.Enable) || c.EnableTLS
@@ -148,7 +155,7 @@ func (c *GNMI) Init() error {
 			return err
 		}
 		if c.TagSubscriptions[idx].TagOnly != c.TagSubscriptions[0].TagOnly {
-			return fmt.Errorf("do not mix legacy tag_only subscriptions and tag subscriptions")
+			return errors.New("do not mix legacy tag_only subscriptions and tag subscriptions")
 		}
 		switch c.TagSubscriptions[idx].Match {
 		case "":
@@ -161,7 +168,7 @@ func (c *GNMI) Init() error {
 		case "name":
 		case "elements":
 			if len(c.TagSubscriptions[idx].Elements) == 0 {
-				return fmt.Errorf("tag_subscription must have at least one element")
+				return errors.New("tag_subscription must have at least one element")
 			}
 		default:
 			return fmt.Errorf("unknown match type %q for tag-subscription %q", c.TagSubscriptions[idx].Match, c.TagSubscriptions[idx].Name)
@@ -169,7 +176,7 @@ func (c *GNMI) Init() error {
 	}
 
 	// Invert explicit alias list and prefill subscription names
-	c.internalAliases = make(map[string]string, len(c.Subscriptions)+len(c.Aliases)+len(c.TagSubscriptions))
+	c.internalAliases = make(map[*pathInfo]string, len(c.Subscriptions)+len(c.Aliases)+len(c.TagSubscriptions))
 	for _, s := range c.Subscriptions {
 		if err := s.buildAlias(c.internalAliases); err != nil {
 			return err
@@ -181,7 +188,7 @@ func (c *GNMI) Init() error {
 		}
 	}
 	for alias, encodingPath := range c.Aliases {
-		c.internalAliases[encodingPath] = alias
+		c.internalAliases[newInfoFromString(encodingPath)] = alias
 	}
 	c.Log.Debugf("Internal alias mapping: %+v", c.internalAliases)
 
@@ -224,6 +231,7 @@ func (c *GNMI) Start(acc telegraf.Accumulator) error {
 				trace:               c.Trace,
 				canonicalFieldNames: c.CanonicalFieldNames,
 				trimSlash:           c.TrimFieldNames,
+				guessPathStrategy:   c.GuessPathStrategy,
 				log:                 c.Log,
 			}
 			for ctx.Err() == nil {
@@ -362,26 +370,21 @@ func (s *Subscription) buildFullPath(c *GNMI) error {
 	return nil
 }
 
-func (s *Subscription) buildAlias(aliases map[string]string) error {
+func (s *Subscription) buildAlias(aliases map[*pathInfo]string) error {
 	// Build the subscription path without keys
-	gnmiPath, err := parsePath(s.Origin, s.Path, "")
+	path, err := parsePath(s.Origin, s.Path, "")
 	if err != nil {
 		return err
 	}
-
-	origin, spath, _, err := handlePath(gnmiPath, nil, nil, "")
-	if err != nil {
-		return fmt.Errorf("handling path failed: %w", err)
-	}
+	info := newInfoFromPathWithoutKeys(path)
 
 	// If the user didn't provide a measurement name, use last path element
 	name := s.Name
-	if name == "" {
-		name = path.Base(spath)
+	if name == "" && len(info.segments) > 0 {
+		name = info.segments[len(info.segments)-1]
 	}
 	if name != "" {
-		aliases[origin+spath] = name
-		aliases[spath] = name
+		aliases[info] = name
 	}
 	return nil
 }
