@@ -4,7 +4,6 @@ import (
 	"context"
 	"encoding/json"
 	"errors"
-	"fmt"
 	"net"
 	"os"
 	"path/filepath"
@@ -13,14 +12,17 @@ import (
 	"time"
 
 	gnmiLib "github.com/openconfig/gnmi/proto/gnmi"
+	gnmiExt "github.com/openconfig/gnmi/proto/gnmi_ext"
 	"github.com/stretchr/testify/require"
 	"google.golang.org/grpc"
 	"google.golang.org/grpc/metadata"
 	"google.golang.org/protobuf/encoding/protojson"
+	"google.golang.org/protobuf/proto"
 
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/plugins/inputs"
+	jnprHeader "github.com/influxdata/telegraf/plugins/inputs/gnmi/extensions/jnpr_gnmi_extention"
 	"github.com/influxdata/telegraf/plugins/parsers/influx"
 	"github.com/influxdata/telegraf/testutil"
 )
@@ -41,7 +43,7 @@ func TestParsePath(t *testing.T) {
 
 	parsed, err = parsePath("", "/foo[[", "")
 	require.Nil(t, parsed)
-	require.NotNil(t, err)
+	require.Error(t, err)
 }
 
 type MockServer struct {
@@ -71,8 +73,8 @@ func TestWaitError(t *testing.T) {
 
 	grpcServer := grpc.NewServer()
 	gnmiServer := &MockServer{
-		SubscribeF: func(server gnmiLib.GNMI_SubscribeServer) error {
-			return fmt.Errorf("testerror")
+		SubscribeF: func(gnmiLib.GNMI_SubscribeServer) error {
+			return errors.New("testerror")
 		},
 		GRPCServer: grpcServer,
 	}
@@ -86,8 +88,8 @@ func TestWaitError(t *testing.T) {
 	}
 
 	var acc testutil.Accumulator
-	err = plugin.Start(&acc)
-	require.NoError(t, err)
+	require.NoError(t, plugin.Init())
+	require.NoError(t, plugin.Start(&acc))
 
 	var wg sync.WaitGroup
 	wg.Add(1)
@@ -145,8 +147,8 @@ func TestUsernamePassword(t *testing.T) {
 	}
 
 	var acc testutil.Accumulator
-	err = plugin.Start(&acc)
-	require.NoError(t, err)
+	require.NoError(t, plugin.Init())
+	require.NoError(t, plugin.Start(&acc))
 
 	var wg sync.WaitGroup
 	wg.Add(1)
@@ -903,6 +905,91 @@ func TestNotification(t *testing.T) {
 				),
 			},
 		},
+		{
+			name: "Juniper Extension",
+			plugin: &GNMI{
+				Log:            testutil.Logger{},
+				Encoding:       "proto",
+				VendorSpecific: []string{"juniper_header"},
+				Redial:         config.Duration(1 * time.Second),
+				Subscriptions: []Subscription{
+					{
+						Name:             "type",
+						Origin:           "openconfig-platform",
+						Path:             "/components/component[name=CHASSIS0:FPC0]/state",
+						SubscriptionMode: "sample",
+						SampleInterval:   config.Duration(1 * time.Second),
+					},
+				},
+			},
+			server: &MockServer{
+				SubscribeF: func(server gnmiLib.GNMI_SubscribeServer) error {
+					if err := server.Send(&gnmiLib.SubscribeResponse{Response: &gnmiLib.SubscribeResponse_SyncResponse{SyncResponse: true}}); err != nil {
+						return err
+					}
+					response := &gnmiLib.SubscribeResponse{
+						Response: &gnmiLib.SubscribeResponse_Update{
+							Update: &gnmiLib.Notification{
+								Timestamp: 1668771585733542546,
+								Prefix: &gnmiLib.Path{
+									Elem: []*gnmiLib.PathElem{
+										{Name: "openconfig-platform:components"},
+										{Name: "component", Key: map[string]string{"name": "CHASSIS0:FPC0"}},
+										{Name: "state"},
+									},
+									Target: "OC-YANG",
+								},
+								Update: []*gnmiLib.Update{
+									{
+										Path: &gnmiLib.Path{
+											Elem: []*gnmiLib.PathElem{
+												{Name: "type"},
+											}},
+										Val: &gnmiLib.TypedValue{
+											Value: &gnmiLib.TypedValue_StringVal{StringVal: "LINECARD"},
+										},
+									},
+								},
+							},
+						},
+						Extension: []*gnmiExt.Extension{{
+							Ext: &gnmiExt.Extension_RegisteredExt{
+								RegisteredExt: &gnmiExt.RegisteredExtension{
+									// Juniper Header Extension
+									//EID_JUNIPER_TELEMETRY_HEADER = 1;
+									Id: 1,
+									Msg: func(jnprExt *jnprHeader.GnmiJuniperTelemetryHeaderExtension) []byte {
+										b, err := proto.Marshal(jnprExt)
+										if err != nil {
+											return nil
+										}
+										return b
+									}(&jnprHeader.GnmiJuniperTelemetryHeaderExtension{ComponentId: 15, SubComponentId: 1, Component: "PICD"}),
+								},
+							},
+						}},
+					}
+					return server.Send(response)
+				},
+			},
+			expected: []telegraf.Metric{
+				testutil.MustMetric(
+					"type",
+					map[string]string{
+						"path":             "openconfig-platform:/components/component/state",
+						"source":           "127.0.0.1",
+						"name":             "CHASSIS0:FPC0",
+						"component_id":     "15",
+						"sub_component_id": "1",
+						"component":        "PICD",
+					},
+					map[string]interface{}{
+						"type": "LINECARD",
+					},
+					time.Unix(0, 0),
+				),
+			},
+		},
 	}
 
 	for _, tt := range tests {
@@ -917,8 +1004,8 @@ func TestNotification(t *testing.T) {
 			gnmiLib.RegisterGNMIServer(grpcServer, tt.server)
 
 			var acc testutil.Accumulator
-			err = tt.plugin.Start(&acc)
-			require.NoError(t, err)
+			require.NoError(t, tt.plugin.Init())
+			require.NoError(t, tt.plugin.Start(&acc))
 
 			var wg sync.WaitGroup
 			wg.Add(1)
@@ -981,8 +1068,8 @@ func TestRedial(t *testing.T) {
 	}()
 
 	var acc testutil.Accumulator
-	err = plugin.Start(&acc)
-	require.NoError(t, err)
+	require.NoError(t, plugin.Init())
+	require.NoError(t, plugin.Start(&acc))
 
 	acc.Wait(2)
 	grpcServer.Stop()
@@ -1117,6 +1204,7 @@ func TestCases(t *testing.T) {
 			}()
 
 			var acc testutil.Accumulator
+			require.NoError(t, plugin.Init())
 			require.NoError(t, plugin.Start(&acc))
 
 			require.Eventually(t,
