@@ -4,6 +4,7 @@ package internet_speed
 import (
 	"context"
 	_ "embed"
+	"errors"
 	"fmt"
 	"math"
 	"os"
@@ -121,9 +122,14 @@ func (is *InternetSpeed) Gather(acc telegraf.Accumulator) error {
 }
 
 func (is *InternetSpeed) findClosestServer() error {
+	proto := speedtest.HTTP
+	if os.Getegid() <= 0 {
+		proto = speedtest.ICMP
+	}
+
 	client := speedtest.New(speedtest.WithUserConfig(&speedtest.UserConfig{
 		UserAgent:  internal.ProductToken(),
-		ICMP:       os.Geteuid() == 0 || os.Geteuid() == -1,
+		PingMode:   proto,
 		SavingMode: is.MemorySavingMode,
 	}))
 	if is.Connections > 0 {
@@ -137,7 +143,7 @@ func (is *InternetSpeed) findClosestServer() error {
 	}
 
 	if len(is.servers) < 1 {
-		return fmt.Errorf("no servers found")
+		return errors.New("no servers found")
 	}
 
 	// Return the first match or the server with the lowest latency
@@ -163,7 +169,7 @@ func (is *InternetSpeed) findClosestServer() error {
 		return nil
 	}
 
-	return fmt.Errorf("no server set: filter excluded all servers or no available server found")
+	return errors.New("no server set: filter excluded all servers or no available server found")
 }
 
 func init() {
