@@ -73,18 +73,31 @@ func (i *Ipset) Gather(acc telegraf.Accumulator) error {
 				"set":  data[1],
 				"rule": data[2],
 			}
-			packetsTotal, err := strconv.ParseUint(data[4], 10, 64)
-			if err != nil {
-				acc.AddError(err)
-			}
-			bytesTotal, err := strconv.ParseUint(data[6], 10, 64)
-			if err != nil {
-				acc.AddError(err)
-			}
-			fields := map[string]interface{}{
-				"packets_total": packetsTotal,
-				"bytes_total":   bytesTotal,
+
+			fields := make(map[string]interface{}, 3)
+			for i, field := range data {
+				switch field {
+				case "timeout":
+					val, err := strconv.ParseUint(data[i+1], 10, 64)
+					if err != nil {
+						acc.AddError(err)
+					}
+					fields["timeout"] = val
+				case "packets":
+					val, err := strconv.ParseUint(data[i+1], 10, 64)
+					if err != nil {
+						acc.AddError(err)
+					}
+					fields["packets_total"] = val
+				case "bytes":
+					val, err := strconv.ParseUint(data[i+1], 10, 64)
+					if err != nil {
+						acc.AddError(err)
+					}
+					fields["bytes_total"] = val
+				}
 			}
+
 			acc.AddCounter(measurement, fields, tags)
 		}
 	}
