@@ -3,9 +3,11 @@ package knx_listener
 
 import (
 	_ "embed"
+	"errors"
 	"fmt"
 	"reflect"
 	"sync"
+	"sync/atomic"
 
 	"github.com/vapourismo/knx-go/knx"
 	"github.com/vapourismo/knx-go/knx/dpt"
@@ -14,7 +16,6 @@ import (
 	"github.com/influxdata/telegraf/plugins/inputs"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
 //go:embed sample.conf
 var sampleConfig string
 
@@ -44,22 +45,27 @@ type KNXListener struct {
 	gaTargetMap map[string]addressTarget
 	gaLogbook   map[string]bool
 
-	acc telegraf.Accumulator
-	wg  sync.WaitGroup
+	wg        sync.WaitGroup
+	connected atomic.Bool
 }
 
 func (*KNXListener) SampleConfig() string {
 	return sampleConfig
 }
 
-func (kl *KNXListener) Gather(_ telegraf.Accumulator) error {
+func (kl *KNXListener) Gather(acc telegraf.Accumulator) error {
+	if !kl.connected.Load() {
+		// We got disconnected for some reason, so try to reconnect in every
+		// gather cycle until we are reconnected
+		if err := kl.Start(acc); err != nil {
+			return fmt.Errorf("reconnecting to bus failed: %w", err)
+		}
+	}
+
 	return nil
 }
 
-func (kl *KNXListener) Start(acc telegraf.Accumulator) error {
-	// Store the accumulator for later use
-	kl.acc = acc
-
+func (kl *KNXListener) Init() error {
 	// Setup a logbook to track unknown GAs to avoid log-spamming
 	kl.gaLogbook = make(map[string]bool)
 
@@ -81,11 +87,25 @@ func (kl *KNXListener) Start(acc telegraf.Accumulator) error {
 		}
 	}
 
+	return nil
+}
+
+func (kl *KNXListener) Start(acc telegraf.Accumulator) error {
 	// Connect to the KNX-IP interface
 	kl.Log.Infof("Trying to connect to %q at %q", kl.ServiceType, kl.ServiceAddress)
 	switch kl.ServiceType {
-	case "tunnel":
-		c, err := knx.NewGroupTunnel(kl.ServiceAddress, knx.DefaultTunnelConfig)
+	case "tunnel", "tunnel_udp":
+		tunnelconfig := knx.DefaultTunnelConfig
+		tunnelconfig.UseTCP = false
+		c, err := knx.NewGroupTunnel(kl.ServiceAddress, tunnelconfig)
+		if err != nil {
+			return err
+		}
+		kl.client = &c
+	case "tunnel_tcp":
+		tunnelconfig := knx.DefaultTunnelConfig
+		tunnelconfig.UseTCP = true
+		c, err := knx.NewGroupTunnel(kl.ServiceAddress, tunnelconfig)
 		if err != nil {
 			return err
 		}
@@ -97,21 +117,21 @@ func (kl *KNXListener) Start(acc telegraf.Accumulator) error {
 		}
 		kl.client = &c
 	case "dummy":
-		c, err := NewDummyInterface()
-		if err != nil {
-			return err
-		}
+		c := NewDummyInterface()
 		kl.client = &c
 	default:
 		return fmt.Errorf("invalid interface type: %s", kl.ServiceAddress)
 	}
 	kl.Log.Infof("Connected!")
+	kl.connected.Store(true)
 
 	// Listen to the KNX bus
 	kl.wg.Add(1)
 	go func() {
-		kl.wg.Done()
-		kl.listen()
+		defer kl.wg.Done()
+		kl.listen(acc)
+		kl.connected.Store(false)
+		acc.AddError(errors.New("disconnected from bus"))
 	}()
 
 	return nil
@@ -124,8 +144,14 @@ func (kl *KNXListener) Stop() {
 	}
 }
 
-func (kl *KNXListener) listen() {
+func (kl *KNXListener) listen(acc telegraf.Accumulator) {
 	for msg := range kl.client.Inbound() {
+		if msg.Command == knx.GroupRead {
+			// Ignore GroupValue_Read requests as they would either
+			// - fail to unpack due to invalid data length (DPT != 1) or
+			// - create invalid `false` values as their data always unpacks `0` (DPT 1)
+			continue
+		}
 		// Match GA to DataPointType and measurement name
 		ga := msg.Destination.String()
 		target, ok := kl.gaTargetMap[ga]
@@ -171,7 +197,7 @@ func (kl *KNXListener) listen() {
 			"unit":         target.datapoint.(dpt.DatapointMeta).Unit(),
 			"source":       msg.Source.String(),
 		}
-		kl.acc.AddFields(target.measurement, fields, tags)
+		acc.AddFields(target.measurement, fields, tags)
 	}
 }
 
