@@ -6,6 +6,7 @@ import (
 	"crypto/tls"
 	"crypto/x509"
 	_ "embed"
+	"errors"
 	"fmt"
 	"net/url"
 	"strings"
@@ -68,13 +69,13 @@ func (m *MongoDB) Init() error {
 			InsecureSkipVerify: m.ClientConfig.InsecureSkipVerify,
 		}
 		if len(m.Ssl.CaCerts) == 0 {
-			return fmt.Errorf("you must explicitly set insecure_skip_verify to skip certificate validation")
+			return errors.New("you must explicitly set insecure_skip_verify to skip certificate validation")
 		}
 
 		roots := x509.NewCertPool()
 		for _, caCert := range m.Ssl.CaCerts {
 			if ok := roots.AppendCertsFromPEM([]byte(caCert)); !ok {
-				return fmt.Errorf("failed to parse root certificate")
+				return errors.New("failed to parse root certificate")
 			}
 		}
 		m.tlsConfig.RootCAs = roots
@@ -139,7 +140,7 @@ func (m *MongoDB) setupConnection(connURL string) error {
 			return fmt.Errorf("unable to ping MongoDB: %w", err)
 		}
 
-		m.Log.Errorf("unable to ping MongoDB: %s", err)
+		m.Log.Errorf("Unable to ping MongoDB: %s", err)
 	}
 
 	server := &Server{
@@ -156,7 +157,7 @@ func (m *MongoDB) Stop() {
 	for _, server := range m.clients {
 		ctx, cancel := context.WithTimeout(context.Background(), 10*time.Second)
 		if err := server.client.Disconnect(ctx); err != nil {
-			m.Log.Errorf("disconnecting from %q failed: %s", server, err)
+			m.Log.Errorf("Disconnecting from %q failed: %v", server.hostname, err)
 		}
 		cancel()
 	}
@@ -172,14 +173,14 @@ func (m *MongoDB) Gather(acc telegraf.Accumulator) error {
 			defer wg.Done()
 			if m.DisconnectedServersBehavior == "skip" {
 				if err := srv.ping(); err != nil {
-					m.Log.Debugf("failed to ping server: %s", err)
+					m.Log.Debugf("Failed to ping server: %s", err)
 					return
 				}
 			}
 
 			err := srv.gatherData(acc, m.GatherClusterStatus, m.GatherPerdbStats, m.GatherColStats, m.GatherTopStat, m.ColStatsDbs)
 			if err != nil {
-				m.Log.Errorf("failed to gather data: %s", err)
+				m.Log.Errorf("Failed to gather data: %s", err)
 			}
 		}(client)
 	}
