@@ -24,6 +24,8 @@ import (
 //go:embed sample.conf
 var sampleConfig string
 
+var once sync.Once
+
 var (
 	// 30 Seconds is the default used by paho.mqtt.golang
 	defaultConnectionTimeout      = config.Duration(30 * time.Second)
@@ -46,7 +48,9 @@ type Client interface {
 	AddRoute(topic string, callback mqtt.MessageHandler)
 	Disconnect(quiesce uint)
 }
+
 type ClientFactory func(o *mqtt.ClientOptions) Client
+
 type TopicParsingConfig struct {
 	Topic       string            `toml:"topic"`
 	Measurement string            `toml:"measurement"`
@@ -59,6 +63,7 @@ type TopicParsingConfig struct {
 	SplitFields      []string
 	SplitTopic       []string
 }
+
 type MQTTConsumer struct {
 	Servers                []string             `toml:"servers"`
 	Topics                 []string             `toml:"topics"`
@@ -68,16 +73,14 @@ type MQTTConsumer struct {
 	Password               config.Secret        `toml:"password"`
 	QoS                    int                  `toml:"qos"`
 	ConnectionTimeout      config.Duration      `toml:"connection_timeout"`
+	ClientTrace            bool                 `toml:"client_trace"`
 	MaxUndeliveredMessages int                  `toml:"max_undelivered_messages"`
-	parser                 telegraf.Parser
-
-	MetricBuffer      int `toml:"metric_buffer" deprecated:"0.10.3;1.30.0;option is ignored"`
-	PersistentSession bool
-	ClientID          string `toml:"client_id"`
-
+	PersistentSession      bool                 `toml:"persistent_session"`
+	ClientID               string               `toml:"client_id"`
+	Log                    telegraf.Logger      `toml:"-"`
 	tls.ClientConfig
 
-	Log           telegraf.Logger
+	parser        telegraf.Parser
 	clientFactory ClientFactory
 	client        Client
 	opts          *mqtt.ClientOptions
@@ -102,6 +105,14 @@ func (m *MQTTConsumer) SetParser(parser telegraf.Parser) {
 	m.parser = parser
 }
 func (m *MQTTConsumer) Init() error {
+	if m.ClientTrace {
+		log := &mqttLogger{m.Log}
+		mqtt.ERROR = log
+		mqtt.CRITICAL = log
+		mqtt.WARN = log
+		mqtt.DEBUG = log
+	}
+
 	m.state = Disconnected
 	if m.PersistentSession && m.ClientID == "" {
 		return errors.New("persistent_session requires client_id")
@@ -136,15 +147,15 @@ func (m *MQTTConsumer) Init() error {
 		m.TopicParsing[i].SplitTopic = strings.Split(p.Topic, "/")
 
 		if len(splitMeasurement) != len(m.TopicParsing[i].SplitTopic) && len(splitMeasurement) != 1 {
-			return fmt.Errorf("config error topic parsing: measurement length does not equal topic length")
+			return errors.New("config error topic parsing: measurement length does not equal topic length")
 		}
 
 		if len(m.TopicParsing[i].SplitFields) != len(m.TopicParsing[i].SplitTopic) && p.Fields != "" {
-			return fmt.Errorf("config error topic parsing: fields length does not equal topic length")
+			return errors.New("config error topic parsing: fields length does not equal topic length")
 		}
 
 		if len(m.TopicParsing[i].SplitTags) != len(m.TopicParsing[i].SplitTopic) && p.Tags != "" {
-			return fmt.Errorf("config error topic parsing: tags length does not equal topic length")
+			return errors.New("config error topic parsing: tags length does not equal topic length")
 		}
 	}
 
@@ -246,7 +257,7 @@ func (m *MQTTConsumer) onDelivered(track telegraf.DeliveryInfo) {
 		return
 	}
 
-	if track.Delivered() {
+	if track.Delivered() && m.PersistentSession {
 		msg.Ack()
 	}
 
@@ -261,9 +272,19 @@ func (m *MQTTConsumer) onMessage(_ mqtt.Client, msg mqtt.Message) {
 	m.messagesRecv.Incr(1)
 
 	metrics, err := m.parser.Parse(msg.Payload())
-	if err != nil {
-		msg.Ack()
+	if err != nil || len(metrics) == 0 {
+		if len(metrics) == 0 {
+			once.Do(func() {
+				const msg = "No metrics were created from a message. Verify your parser settings. This message is only printed once."
+				m.Log.Debug(msg)
+			})
+		}
+
+		if m.PersistentSession {
+			msg.Ack()
+		}
 		m.acc.AddError(err)
+		<-m.sem
 		return
 	}
 
@@ -283,23 +304,29 @@ func (m *MQTTConsumer) onMessage(_ mqtt.Client, msg mqtt.Message) {
 			if p.Tags != "" {
 				err := parseMetric(p.SplitTags, values, p.FieldTypes, true, metric)
 				if err != nil {
-					msg.Ack()
+					if m.PersistentSession {
+						msg.Ack()
+					}
 					m.acc.AddError(err)
+					<-m.sem
 					return
 				}
 			}
 			if p.Fields != "" {
 				err := parseMetric(p.SplitFields, values, p.FieldTypes, false, metric)
 				if err != nil {
-					msg.Ack()
+					if m.PersistentSession {
+						msg.Ack()
+					}
 					m.acc.AddError(err)
+					<-m.sem
 					return
 				}
 			}
 		}
 	}
-	id := m.acc.AddTrackingMetricGroup(metrics)
 	m.messagesMutex.Lock()
+	id := m.acc.AddTrackingMetricGroup(metrics)
 	m.messages[id] = msg
 	m.messagesMutex.Unlock()
 }
@@ -343,8 +370,8 @@ func (m *MQTTConsumer) createOpts() (*mqtt.ClientOptions, error) {
 		if err != nil {
 			return nil, fmt.Errorf("getting username failed: %w", err)
 		}
-		opts.SetUsername(string(user))
-		config.ReleaseSecret(user)
+		opts.SetUsername(user.String())
+		user.Destroy()
 	}
 
 	if !m.Password.Empty() {
@@ -352,11 +379,11 @@ func (m *MQTTConsumer) createOpts() (*mqtt.ClientOptions, error) {
 		if err != nil {
 			return nil, fmt.Errorf("getting password failed: %w", err)
 		}
-		opts.SetPassword(string(password))
-		config.ReleaseSecret(password)
+		opts.SetPassword(password.String())
+		password.Destroy()
 	}
 	if len(m.Servers) == 0 {
-		return opts, fmt.Errorf("could not get host information")
+		return opts, errors.New("could not get host information")
 	}
 	for _, server := range m.Servers {
 		// Preserve support for host:port style servers; deprecated in Telegraf 1.4.4
