@@ -36,8 +36,12 @@ func TestMysqlDefaultsToLocalIntegration(t *testing.T) {
 	require.NoError(t, container.Start(), "failed to start container")
 	defer container.Terminate()
 
+	dsn := fmt.Sprintf("root@tcp(%s:%s)/", container.Address, container.Ports[servicePort])
+	s := config.NewSecret([]byte(dsn))
+	defer s.Destroy()
 	m := &Mysql{
-		Servers: []string{fmt.Sprintf("root@tcp(%s:%s)/", container.Address, container.Ports[servicePort])},
+		Servers: []*config.Secret{&s},
+		Log:     &testutil.Logger{},
 	}
 	require.NoError(t, m.Init())
 
@@ -70,12 +74,15 @@ func TestMysqlMultipleInstancesIntegration(t *testing.T) {
 	require.NoError(t, container.Start(), "failed to start container")
 	defer container.Terminate()
 
-	testServer := fmt.Sprintf("root@tcp(%s:%s)/?tls=false", container.Address, container.Ports[servicePort])
+	dsn := fmt.Sprintf("root@tcp(%s:%s)/?tls=false", container.Address, container.Ports[servicePort])
+	s := config.NewSecret([]byte(dsn))
+	defer s.Destroy()
 	m := &Mysql{
-		Servers:          []string{testServer},
+		Servers:          []*config.Secret{&s},
 		IntervalSlow:     config.Duration(30 * time.Second),
 		GatherGlobalVars: true,
 		MetricVersion:    2,
+		Log:              &testutil.Logger{},
 	}
 	require.NoError(t, m.Init())
 
@@ -86,9 +93,11 @@ func TestMysqlMultipleInstancesIntegration(t *testing.T) {
 	// acc should have global variables
 	require.True(t, acc.HasMeasurement("mysql_variables"))
 
+	s2 := config.NewSecret([]byte(dsn))
 	m2 := &Mysql{
-		Servers:       []string{testServer},
+		Servers:       []*config.Secret{&s2},
 		MetricVersion: 2,
+		Log:           &testutil.Logger{},
 	}
 	require.NoError(t, m2.Init())
 
@@ -100,6 +109,83 @@ func TestMysqlMultipleInstancesIntegration(t *testing.T) {
 	require.False(t, acc2.HasMeasurement("mysql_variables"))
 }
 
+func TestPercona8Integration(t *testing.T) {
+	if testing.Short() {
+		t.Skip("Skipping integration test in short mode")
+	}
+
+	container := testutil.Container{
+		Image: "percona:8",
+		Env: map[string]string{
+			"MYSQL_ROOT_PASSWORD": "secret",
+		},
+		Cmd:          []string{"--userstat=ON"},
+		ExposedPorts: []string{servicePort},
+		WaitingFor: wait.ForAll(
+			wait.ForLog("/usr/sbin/mysqld: ready for connections").WithOccurrence(2),
+			wait.ForListeningPort(nat.Port(servicePort)),
+		),
+	}
+	require.NoError(t, container.Start(), "failed to start container")
+	defer container.Terminate()
+
+	dsn := fmt.Sprintf("root:secret@tcp(%s:%s)/", container.Address, container.Ports[servicePort])
+	s := config.NewSecret([]byte(dsn))
+	defer s.Destroy()
+	plugin := &Mysql{
+		Servers:              []*config.Secret{&s},
+		GatherUserStatistics: true,
+		Log:                  &testutil.Logger{},
+	}
+	require.NoError(t, plugin.Init())
+
+	var acc testutil.Accumulator
+	require.NoError(t, plugin.Gather(&acc))
+	require.Empty(t, acc.Errors)
+	require.True(t, acc.HasMeasurement("mysql_user_stats"))
+	require.True(t, acc.HasFloatField("mysql_user_stats", "connected_time"))
+	require.True(t, acc.HasFloatField("mysql_user_stats", "cpu_time"))
+	require.True(t, acc.HasFloatField("mysql_user_stats", "busy_time"))
+}
+
+func TestGaleraIntegration(t *testing.T) {
+	if testing.Short() {
+		t.Skip("Skipping integration test in short mode")
+	}
+
+	container := testutil.Container{
+		Image:        "bitnami/mariadb-galera",
+		Env:          map[string]string{"ALLOW_EMPTY_PASSWORD": "yes"},
+		ExposedPorts: []string{servicePort},
+		WaitingFor: wait.ForAll(
+			wait.ForLog("Synchronized with group, ready for connections"),
+			wait.ForListeningPort(nat.Port(servicePort)),
+		),
+	}
+	require.NoError(t, container.Start(), "failed to start container")
+	defer container.Terminate()
+
+	dsn := fmt.Sprintf("root@tcp(%s:%s)/", container.Address, container.Ports[servicePort])
+	s := config.NewSecret([]byte(dsn))
+	defer s.Destroy()
+	plugin := &Mysql{
+		Servers: []*config.Secret{&s},
+		Log:     &testutil.Logger{},
+	}
+	require.NoError(t, plugin.Init())
+
+	var acc testutil.Accumulator
+	require.NoError(t, plugin.Gather(&acc))
+	require.Empty(t, acc.Errors)
+	require.True(t, acc.HasIntField("mysql", "wsrep_ready"))
+	for _, m := range acc.GetTelegrafMetrics() {
+		if v, found := m.GetField("wsrep_ready"); found {
+			require.EqualValues(t, 1, v, "invalid value for field wsrep_ready")
+			break
+		}
+	}
+}
+
 func TestMysqlGetDSNTag(t *testing.T) {
 	tests := []struct {
 		input  string
@@ -204,9 +290,14 @@ func TestMysqlDNSAddTimeout(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			m := &Mysql{Servers: []string{tt.input}}
+			s := config.NewSecret([]byte(tt.input))
+			m := &Mysql{
+				Servers: []*config.Secret{&s},
+			}
 			require.NoError(t, m.Init())
-			require.Equal(t, tt.output, m.Servers[0])
+			equal, err := m.Servers[0].EqualTo([]byte(tt.output))
+			require.NoError(t, err)
+			require.True(t, equal)
 		})
 	}
 }
@@ -314,7 +405,7 @@ func TestGatherGlobalVariables(t *testing.T) {
 
 			acc := &testutil.Accumulator{}
 
-			err = m.gatherGlobalVariables(db, "test", acc)
+			err := m.gatherGlobalVariables(db, getDSNTag("test"), acc)
 			require.NoErrorf(t, err, "err on gatherGlobalVariables (test case %q)", testCase.name)
 
 			foundFields := map[string]bool{}
