@@ -5,6 +5,7 @@ import (
 	"bufio"
 	"bytes"
 	_ "embed"
+	"encoding/json"
 	"fmt"
 	"io"
 	"net/http"
@@ -40,12 +41,46 @@ const (
 	PfSlowRequests       = "slow requests"
 )
 
-type metric map[string]int64
-type poolStat map[string]metric
+type JSONMetrics struct {
+	Pool               string `json:"pool"`
+	ProcessManager     string `json:"process manager"`
+	StartTime          int    `json:"start time"`
+	StartSince         int    `json:"start since"`
+	AcceptedConn       int    `json:"accepted conn"`
+	ListenQueue        int    `json:"listen queue"`
+	MaxListenQueue     int    `json:"max listen queue"`
+	ListenQueueLen     int    `json:"listen queue len"`
+	IdleProcesses      int    `json:"idle processes"`
+	ActiveProcesses    int    `json:"active processes"`
+	TotalProcesses     int    `json:"total processes"`
+	MaxActiveProcesses int    `json:"max active processes"`
+	MaxChildrenReached int    `json:"max children reached"`
+	SlowRequests       int    `json:"slow requests"`
+	Processes          []struct {
+		Pid               int     `json:"pid"`
+		State             string  `json:"state"`
+		StartTime         int     `json:"start time"`
+		StartSince        int     `json:"start since"`
+		Requests          int     `json:"requests"`
+		RequestDuration   int     `json:"request duration"`
+		RequestMethod     string  `json:"request method"`
+		RequestURI        string  `json:"request uri"`
+		ContentLength     int     `json:"content length"`
+		User              string  `json:"user"`
+		Script            string  `json:"script"`
+		LastRequestCPU    float64 `json:"last request cpu"`
+		LastRequestMemory float64 `json:"last request memory"`
+	} `json:"processes"`
+}
+
+type metricStat map[string]int64
+type poolStat map[string]metricStat
 
 type phpfpm struct {
-	Urls    []string
-	Timeout config.Duration
+	Format  string          `toml:"format"`
+	Timeout config.Duration `toml:"timeout"`
+	Urls    []string        `toml:"urls"`
+	Log     telegraf.Logger `toml:"-"`
 	tls.ClientConfig
 
 	client *http.Client
@@ -56,11 +91,24 @@ func (*phpfpm) SampleConfig() string {
 }
 
 func (p *phpfpm) Init() error {
+	if len(p.Urls) == 0 {
+		p.Urls = []string{"http://127.0.0.1/status"}
+	}
+
 	tlsCfg, err := p.ClientConfig.TLSConfig()
 	if err != nil {
 		return err
 	}
 
+	switch p.Format {
+	case "":
+		p.Format = "status"
+	case "status", "json":
+		// both valid
+	default:
+		return fmt.Errorf("invalid format: %s", p.Format)
+	}
+
 	p.client = &http.Client{
 		Transport: &http.Transport{
 			TLSClientConfig: tlsCfg,
@@ -73,18 +121,8 @@ func (p *phpfpm) Init() error {
 // Reads stats from all configured servers accumulates stats.
 // Returns one of the errors encountered while gather stats (if any).
 func (p *phpfpm) Gather(acc telegraf.Accumulator) error {
-	if len(p.Urls) == 0 {
-		return p.gatherServer("http://127.0.0.1/status", acc)
-	}
-
 	var wg sync.WaitGroup
-
-	urls, err := expandUrls(p.Urls)
-	if err != nil {
-		return err
-	}
-
-	for _, serv := range urls {
+	for _, serv := range expandUrls(acc, p.Urls) {
 		wg.Add(1)
 		go func(serv string) {
 			defer wg.Done()
@@ -116,9 +154,12 @@ func (p *phpfpm) gatherServer(addr string, acc telegraf.Accumulator) error {
 			return fmt.Errorf("unable parse server address %q: %w", addr, err)
 		}
 		socketAddr := strings.Split(u.Host, ":")
+		if len(socketAddr) < 2 {
+			return fmt.Errorf("url does not follow required 'address:port' format: %s", u.Host)
+		}
 		fcgiIP := socketAddr[0]
 		fcgiPort, _ := strconv.Atoi(socketAddr[1])
-		fcgi, err = newFcgiClient(fcgiIP, fcgiPort)
+		fcgi, err = newFcgiClient(time.Duration(p.Timeout), fcgiIP, fcgiPort)
 		if err != nil {
 			return err
 		}
@@ -132,7 +173,7 @@ func (p *phpfpm) gatherServer(addr string, acc telegraf.Accumulator) error {
 		if statusPath == "" {
 			statusPath = "status"
 		}
-		fcgi, err = newFcgiClient("unix", socketPath)
+		fcgi, err = newFcgiClient(time.Duration(p.Timeout), "unix", socketPath)
 	}
 
 	if err != nil {
@@ -155,7 +196,7 @@ func (p *phpfpm) gatherFcgi(fcgi *conn, statusPath string, acc telegraf.Accumula
 	}, "/"+statusPath)
 
 	if len(fpmErr) == 0 && err == nil {
-		importMetric(bytes.NewReader(fpmOutput), acc, addr)
+		p.importMetric(bytes.NewReader(fpmOutput), acc, addr)
 		return nil
 	}
 	return fmt.Errorf("unable parse phpfpm status, error: %s; %w", string(fpmErr), err)
@@ -183,12 +224,20 @@ func (p *phpfpm) gatherHTTP(addr string, acc telegraf.Accumulator) error {
 		return fmt.Errorf("unable to get valid stat result from %q: %w", addr, err)
 	}
 
-	importMetric(res.Body, acc, addr)
+	p.importMetric(res.Body, acc, addr)
 	return nil
 }
 
 // Import stat data into Telegraf system
-func importMetric(r io.Reader, acc telegraf.Accumulator, addr string) {
+func (p *phpfpm) importMetric(r io.Reader, acc telegraf.Accumulator, addr string) {
+	if p.Format == "json" {
+		p.parseJSON(r, acc, addr)
+	} else {
+		parseLines(r, acc, addr)
+	}
+}
+
+func parseLines(r io.Reader, acc telegraf.Accumulator, addr string) {
 	stats := make(poolStat)
 	var currentPool string
 
@@ -204,7 +253,7 @@ func importMetric(r io.Reader, acc telegraf.Accumulator, addr string) {
 		// We start to gather data for a new pool here
 		if fieldName == PfPool {
 			currentPool = strings.Trim(keyvalue[1], " ")
-			stats[currentPool] = make(metric)
+			stats[currentPool] = make(metricStat)
 			continue
 		}
 
@@ -242,7 +291,57 @@ func importMetric(r io.Reader, acc telegraf.Accumulator, addr string) {
 	}
 }
 
-func expandUrls(urls []string) ([]string, error) {
+func (p *phpfpm) parseJSON(r io.Reader, acc telegraf.Accumulator, addr string) {
+	var metrics JSONMetrics
+	if err := json.NewDecoder(r).Decode(&metrics); err != nil {
+		p.Log.Errorf("Unable to decode JSON response: %s", err)
+		return
+	}
+	timestamp := time.Now()
+
+	tags := map[string]string{
+		"pool": metrics.Pool,
+		"url":  addr,
+	}
+	fields := map[string]any{
+		"start_since":          metrics.StartSince,
+		"accepted_conn":        metrics.AcceptedConn,
+		"listen_queue":         metrics.ListenQueue,
+		"max_listen_queue":     metrics.MaxListenQueue,
+		"listen_queue_len":     metrics.ListenQueueLen,
+		"idle_processes":       metrics.IdleProcesses,
+		"active_processes":     metrics.ActiveProcesses,
+		"total_processes":      metrics.TotalProcesses,
+		"max_active_processes": metrics.MaxActiveProcesses,
+		"max_children_reached": metrics.MaxChildrenReached,
+		"slow_requests":        metrics.SlowRequests,
+	}
+	acc.AddFields("phpfpm", fields, tags, timestamp)
+
+	for _, process := range metrics.Processes {
+		tags := map[string]string{
+			"pool":           metrics.Pool,
+			"url":            addr,
+			"user":           process.User,
+			"request_uri":    process.RequestURI,
+			"request_method": process.RequestMethod,
+			"script":         process.Script,
+		}
+		fields := map[string]any{
+			"pid":                 process.Pid,
+			"state":               process.State,
+			"start_time":          process.StartTime,
+			"requests":            process.Requests,
+			"request_duration":    process.RequestDuration,
+			"content_length":      process.ContentLength,
+			"last_request_cpu":    process.LastRequestCPU,
+			"last_request_memory": process.LastRequestMemory,
+		}
+		acc.AddFields("phpfpm_process", fields, tags, timestamp)
+	}
+}
+
+func expandUrls(acc telegraf.Accumulator, urls []string) []string {
 	addrs := make([]string, 0, len(urls))
 	for _, address := range urls {
 		if isNetworkURL(address) {
@@ -251,11 +350,12 @@ func expandUrls(urls []string) ([]string, error) {
 		}
 		paths, err := globUnixSocket(address)
 		if err != nil {
-			return nil, err
+			acc.AddError(err)
+			continue
 		}
 		addrs = append(addrs, paths...)
 	}
-	return addrs, nil
+	return addrs
 }
 
 func globUnixSocket(address string) ([]string, error) {
