@@ -60,7 +60,7 @@ func TestHost(t *testing.T) {
 	require.Equal(t, 52, stats.max, "Max 52")
 }
 
-func mockHostPinger(_ string, _ float64, _ ...string) (string, error) {
+func mockHostPinger(string, float64, ...string) (string, error) {
 	return winENPingOutput, nil
 }
 
@@ -103,7 +103,7 @@ Statystyka badania ping dla 195.187.242.157:
              (100% straty),
 `
 
-func mockErrorHostPinger(_ string, _ float64, _ ...string) (string, error) {
+func mockErrorHostPinger(string, float64, ...string) (string, error) {
 	return errorPingOutput, errors.New("No packets received")
 }
 
@@ -164,7 +164,7 @@ Szacunkowy czas błądzenia pakietów w millisekundach:
     Minimum = 114 ms, Maksimum = 119 ms, Czas średni = 115 ms
 `
 
-func mockLossyHostPinger(_ string, _ float64, _ ...string) (string, error) {
+func mockLossyHostPinger(string, float64, ...string) (string, error) {
 	return lossyPingOutput, nil
 }
 
@@ -227,7 +227,7 @@ Options:
 
 `
 
-func mockFatalHostPinger(_ string, _ float64, _ ...string) (string, error) {
+func mockFatalHostPinger(string, float64, ...string) (string, error) {
 	return fatalPingOutput, errors.New("So very bad")
 }
 
@@ -272,7 +272,7 @@ Ping statistics for 8.8.8.8:
     Packets: Sent = 4, Received = 1, Lost = 3 (75% loss),
 `
 
-func mockUnreachableHostPinger(_ string, _ float64, _ ...string) (string, error) {
+func mockUnreachableHostPinger(string, float64, ...string) (string, error) {
 	return UnreachablePingOutput, errors.New("So very bad")
 }
 
@@ -323,7 +323,7 @@ Ping statistics for 8.8.8.8:
     Packets: Sent = 4, Received = 1, Lost = 3 (75% loss),
 `
 
-func mockTTLExpiredPinger(_ string, _ float64, _ ...string) (string, error) {
+func mockTTLExpiredPinger(string, float64, ...string) (string, error) {
 	return TTLExpiredPingOutput, errors.New("So very bad")
 }
 
@@ -367,7 +367,7 @@ func TestPingBinary(t *testing.T) {
 		Log:    testutil.Logger{},
 		Urls:   []string{"www.google.com"},
 		Binary: "ping6",
-		pingHost: func(binary string, timeout float64, args ...string) (string, error) {
+		pingHost: func(binary string, _ float64, _ ...string) (string, error) {
 			require.Equal(t, "ping6", binary)
 			return "", nil
 		},
