@@ -8,7 +8,10 @@ import (
 	"errors"
 	"fmt"
 	"io/fs"
+	"strings"
+	"syscall"
 
+	"golang.org/x/sys/windows"
 	"golang.org/x/sys/windows/svc"
 	"golang.org/x/sys/windows/svc/mgr"
 
@@ -67,8 +70,17 @@ func (m *WinSvcMgr) Disconnect() error {
 }
 
 func (m *WinSvcMgr) OpenService(name string) (WinService, error) {
-	return m.realMgr.OpenService(name)
+	serviceName, err := syscall.UTF16PtrFromString(name)
+	if err != nil {
+		return nil, fmt.Errorf("cannot convert service name %q: %w", name, err)
+	}
+	h, err := windows.OpenService(m.realMgr.Handle, serviceName, windows.GENERIC_READ)
+	if err != nil {
+		return nil, err
+	}
+	return &mgr.Service{Name: name, Handle: h}, nil
 }
+
 func (m *WinSvcMgr) ListServices() ([]string, error) {
 	return m.realMgr.ListServices()
 }
@@ -78,10 +90,11 @@ type MgProvider struct {
 }
 
 func (rmr *MgProvider) Connect() (WinServiceManager, error) {
-	scmgr, err := mgr.Connect()
+	h, err := windows.OpenSCManager(nil, nil, windows.GENERIC_READ)
 	if err != nil {
 		return nil, err
 	}
+	scmgr := &mgr.Mgr{Handle: h}
 	return &WinSvcMgr{scmgr}, nil
 }
 
@@ -108,11 +121,22 @@ func (*WinServices) SampleConfig() string {
 }
 
 func (m *WinServices) Init() error {
-	var err error
-	m.servicesFilter, err = filter.NewIncludeExcludeFilter(m.ServiceNames, m.ServiceNamesExcluded)
+	// For case insensitive comparison (see issue #8796) we need to transform the services
+	// to lowercase
+	servicesInclude := make([]string, 0, len(m.ServiceNames))
+	for _, s := range m.ServiceNames {
+		servicesInclude = append(servicesInclude, strings.ToLower(s))
+	}
+	servicesExclude := make([]string, 0, len(m.ServiceNamesExcluded))
+	for _, s := range m.ServiceNamesExcluded {
+		servicesExclude = append(servicesExclude, strings.ToLower(s))
+	}
+
+	f, err := filter.NewIncludeExcludeFilter(servicesInclude, servicesExclude)
 	if err != nil {
 		return err
 	}
+	m.servicesFilter = f
 
 	return nil
 }
@@ -166,9 +190,11 @@ func (m *WinServices) listServices(scmgr WinServiceManager) ([]string, error) {
 	}
 
 	var services []string
-	for _, n := range names {
+	for _, name := range names {
+		// Compare case-insensitive. Use lowercase as we already converted the filter to use it.
+		n := strings.ToLower(name)
 		if m.servicesFilter.Match(n) {
-			services = append(services, n)
+			services = append(services, name)
 		}
 	}
 
