@@ -220,7 +220,7 @@ func newPostgresqlTest(tb testing.TB) *PostgresqlTest {
 		},
 		WaitingFor: wait.ForAll(
 			// the database comes up twice, once right away, then again a second
-			// time after the docker entrypoint starts configuraiton
+			// time after the docker entrypoint starts configuration
 			wait.ForLog("database system is ready to accept connections").WithOccurrence(2),
 			wait.ForListeningPort(nat.Port(servicePort)),
 		),
@@ -687,7 +687,7 @@ func TestWriteIntegration_tagError(t *testing.T) {
 	require.EqualValues(t, 2, dump[1]["v"])
 }
 
-// Verify that when using TagsAsForeignKeys and ForeignTagConstraing and a tag can't be written, that we drop the metrics.
+// Verify that when using TagsAsForeignKeys and ForeignTagConstraint and a tag can't be written, that we drop the metrics.
 func TestWriteIntegration_tagError_foreignConstraint(t *testing.T) {
 	if testing.Short() {
 		t.Skip("Skipping integration test in short mode")
@@ -761,7 +761,7 @@ func TestWriteIntegration_UnsignedIntegers(t *testing.T) {
 	p.Uint64Type = PgUint8
 	_ = p.Init()
 	if err := p.Connect(); err != nil {
-		if strings.Contains(err.Error(), "retreiving OID for uint8 data type") {
+		if strings.Contains(err.Error(), "retrieving OID for uint8 data type") {
 			t.Skipf("pguint extension is not installed")
 			t.SkipNow()
 		}
