@@ -91,7 +91,7 @@ func (t *TopK) generateGroupByKey(m telegraf.Metric) (string, error) {
 		var err error
 		t.tagsGlobs, err = filter.Compile(t.GroupBy)
 		if err != nil {
-			return "", fmt.Errorf("could not compile pattern: %v %v", t.GroupBy, err)
+			return "", fmt.Errorf("could not compile pattern: %v %w", t.GroupBy, err)
 		}
 	}
 
@@ -163,7 +163,7 @@ func (t *TopK) Apply(in ...telegraf.Metric) []telegraf.Metric {
 		// holding undelivered metrics while the input waits for metrics to be
 		// delivered.  Instead, treat all handled metrics as delivered and
 		// produced metrics as untracked in a similar way to aggregators.
-		m.Drop()
+		m.Accept()
 
 		// Check if the metric has any of the fields over which we are aggregating
 		hasField := false
@@ -285,7 +285,7 @@ func (t *TopK) getAggregationFunction(aggOperation string) (func([]telegraf.Metr
 				}
 				val, ok := convert(fieldVal)
 				if !ok {
-					t.Log.Infof("Cannot convert value '%s' from metric '%s' with tags '%s'",
+					t.Log.Infof("Cannot convert value %q from metric %q with tags %q",
 						m.Fields()[field], m.Name(), m.Tags())
 					continue
 				}
@@ -351,7 +351,7 @@ func (t *TopK) getAggregationFunction(aggOperation string) (func([]telegraf.Metr
 					}
 					val, ok := convert(fieldVal)
 					if !ok {
-						t.Log.Infof("Cannot convert value '%s' from metric '%s' with tags '%s'",
+						t.Log.Infof("Cannot convert value %q from metric %q with tags %q",
 							m.Fields()[field], m.Name(), m.Tags())
 						continue
 					}
@@ -377,7 +377,7 @@ func (t *TopK) getAggregationFunction(aggOperation string) (func([]telegraf.Metr
 		}, nil
 
 	default:
-		return nil, fmt.Errorf("unknown aggregation function '%s', no metrics will be processed", t.Aggregation)
+		return nil, fmt.Errorf("unknown aggregation function %q, no metrics will be processed", t.Aggregation)
 	}
 }
 
