@@ -10,48 +10,55 @@ import (
 	"github.com/blues/jsonata-go"
 
 	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/filter"
+	"github.com/influxdata/telegraf/plugins/serializers"
 )
 
-type FormatConfig struct {
-	TimestampUnits      time.Duration
-	TimestampFormat     string
-	Transformation      string
-	NestedFieldsInclude []string
-	NestedFieldsExclude []string
-}
-
 type Serializer struct {
-	TimestampUnits  time.Duration
-	TimestampFormat string
+	TimestampUnits      config.Duration `toml:"json_timestamp_units"`
+	TimestampFormat     string          `toml:"json_timestamp_format"`
+	Transformation      string          `toml:"json_transformation"`
+	NestedFieldsInclude []string        `toml:"json_nested_fields_include"`
+	NestedFieldsExclude []string        `toml:"json_nested_fields_exclude"`
 
-	transformation string
-	nestedfields   filter.Filter
+	nestedfields filter.Filter
 }
 
-func NewSerializer(cfg FormatConfig) (*Serializer, error) {
-	s := &Serializer{
-		TimestampUnits:  truncateDuration(cfg.TimestampUnits),
-		TimestampFormat: cfg.TimestampFormat,
-		transformation:  cfg.Transformation,
+func (s *Serializer) Init() error {
+	// Default precision is 1s
+	if s.TimestampUnits <= 0 {
+		s.TimestampUnits = config.Duration(time.Second)
 	}
 
-	if len(cfg.NestedFieldsInclude) > 0 || len(cfg.NestedFieldsExclude) > 0 {
-		f, err := filter.NewIncludeExcludeFilter(cfg.NestedFieldsInclude, cfg.NestedFieldsExclude)
+	// Search for the power of ten less than the duration
+	d := time.Nanosecond
+	t := time.Duration(s.TimestampUnits)
+	for {
+		if d*10 > t {
+			t = d
+			break
+		}
+		d = d * 10
+	}
+	s.TimestampUnits = config.Duration(t)
+
+	if len(s.NestedFieldsInclude) > 0 || len(s.NestedFieldsExclude) > 0 {
+		f, err := filter.NewIncludeExcludeFilter(s.NestedFieldsInclude, s.NestedFieldsExclude)
 		if err != nil {
-			return nil, err
+			return err
 		}
 		s.nestedfields = f
 	}
 
-	return s, nil
+	return nil
 }
 
 func (s *Serializer) Serialize(metric telegraf.Metric) ([]byte, error) {
 	var obj interface{}
 	obj = s.createObject(metric)
 
-	if s.transformation != "" {
+	if s.Transformation != "" {
 		var err error
 		if obj, err = s.transform(obj); err != nil {
 			if errors.Is(err, jsonata.ErrUndefined) {
@@ -82,7 +89,7 @@ func (s *Serializer) SerializeBatch(metrics []telegraf.Metric) ([]byte, error) {
 		"metrics": objects,
 	}
 
-	if s.transformation != "" {
+	if s.Transformation != "" {
 		var err error
 		if obj, err = s.transform(obj); err != nil {
 			if errors.Is(err, jsonata.ErrUndefined) {
@@ -96,6 +103,8 @@ func (s *Serializer) SerializeBatch(metrics []telegraf.Metric) ([]byte, error) {
 	if err != nil {
 		return []byte{}, err
 	}
+	serialized = append(serialized, '\n')
+
 	return serialized, nil
 }
 
@@ -143,7 +152,7 @@ func (s *Serializer) createObject(metric telegraf.Metric) map[string]interface{}
 }
 
 func (s *Serializer) transform(obj interface{}) (interface{}, error) {
-	transformation, err := jsonata.Compile(s.transformation)
+	transformation, err := jsonata.Compile(s.Transformation)
 	if err != nil {
 		return nil, err
 	}
@@ -151,18 +160,21 @@ func (s *Serializer) transform(obj interface{}) (interface{}, error) {
 	return transformation.Eval(obj)
 }
 
-func truncateDuration(units time.Duration) time.Duration {
-	// Default precision is 1s
-	if units <= 0 {
-		return time.Second
-	}
+func init() {
+	serializers.Add("json",
+		func() serializers.Serializer {
+			return &Serializer{}
+		},
+	)
+}
 
-	// Search for the power of ten less than the duration
-	d := time.Nanosecond
-	for {
-		if d*10 > units {
-			return d
-		}
-		d = d * 10
-	}
+// InitFromConfig is a compatibility function to construct the parser the old way
+func (s *Serializer) InitFromConfig(cfg *serializers.Config) error {
+	s.TimestampUnits = config.Duration(cfg.TimestampUnits)
+	s.TimestampFormat = cfg.TimestampFormat
+	s.Transformation = cfg.Transformation
+	s.NestedFieldsInclude = cfg.JSONNestedFieldInclude
+	s.NestedFieldsExclude = cfg.JSONNestedFieldExclude
+
+	return nil
 }
