@@ -7,6 +7,7 @@ import (
 
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/metric"
+	"github.com/influxdata/telegraf/plugins/serializers"
 	"github.com/influxdata/telegraf/testutil"
 )
 
@@ -27,7 +28,7 @@ func TestSerializeMetricInt(t *testing.T) {
 	left, err := m2.UnmarshalMsg(buf)
 	require.NoError(t, err)
 
-	require.Equal(t, len(left), 0)
+	require.Empty(t, left)
 
 	testutil.RequireMetricEqual(t, m, toTelegrafMetric(*m2))
 }
@@ -44,7 +45,7 @@ func TestSerializeMetricString(t *testing.T) {
 	left, err := m2.UnmarshalMsg(buf)
 	require.NoError(t, err)
 
-	require.Equal(t, len(left), 0)
+	require.Empty(t, left)
 
 	testutil.RequireMetricEqual(t, m, toTelegrafMetric(*m2))
 }
@@ -62,7 +63,7 @@ func TestSerializeMultiFields(t *testing.T) {
 	left, err := m2.UnmarshalMsg(buf)
 	require.NoError(t, err)
 
-	require.Equal(t, len(left), 0)
+	require.Empty(t, left)
 
 	testutil.RequireMetricEqual(t, m, toTelegrafMetric(*m2))
 }
@@ -81,7 +82,7 @@ func TestSerializeMetricWithEscapes(t *testing.T) {
 	left, err := m2.UnmarshalMsg(buf)
 	require.NoError(t, err)
 
-	require.Equal(t, len(left), 0)
+	require.Empty(t, left)
 
 	testutil.RequireMetricEqual(t, m, toTelegrafMetric(*m2))
 }
@@ -94,7 +95,7 @@ func TestSerializeMultipleMetric(t *testing.T) {
 	encoded, err := s.Serialize(m)
 	require.NoError(t, err)
 
-	// Multiple metrics in continous bytes stream
+	// Multiple metrics in continuous bytes stream
 	var buf []byte
 	buf = append(buf, encoded...)
 	buf = append(buf, encoded...)
@@ -130,3 +131,24 @@ func TestSerializeBatch(t *testing.T) {
 		testutil.RequireMetricEqual(t, m, toTelegrafMetric(*decodeM))
 	}
 }
+
+func BenchmarkSerialize(b *testing.B) {
+	s := &Serializer{}
+	metrics := serializers.BenchmarkMetrics(b)
+	b.ResetTimer()
+	for i := 0; i < b.N; i++ {
+		_, err := s.Serialize(metrics[i%len(metrics)])
+		require.NoError(b, err)
+	}
+}
+
+func BenchmarkSerializeBatch(b *testing.B) {
+	s := &Serializer{}
+	m := serializers.BenchmarkMetrics(b)
+	metrics := m[:]
+	b.ResetTimer()
+	for i := 0; i < b.N; i++ {
+		_, err := s.SerializeBatch(metrics)
+		require.NoError(b, err)
+	}
+}
